@@ -250,6 +250,9 @@ OC.L10N.register(
     "Completed on %s" : "Críochnaithe ar %s",
     "Due on %s by %s" : "Dlite ar %s faoi %s",
     "Due on %s" : "Dlite ar %s",
+    "System Address Book" : "Leabhar Seoltaí Córais",
+    "The system address book contains contact information for all users in your instance." : "Tá faisnéis teagmhála i leabhar seoltaí an chórais do gach úsáideoir i do chás.",
+    "Enable System Address Book" : "Cumasaigh Leabhar Seoltaí an Chórais",
     "DAV system address book" : "Leabhar seoltaí córas DAV",
     "No outstanding DAV system address book sync." : "Níl sioncronú leabhar seoltaí córais DAV gan íoc.",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Níor rith sioncronú leabhar seoltaí an chórais DAV fós toisc go bhfuil níos mó ná 1000 úsáideoir ag do chás nó toisc gur tharla earráid. Rith de láimh é le do thoil trí ghlao a chur ar \"occ dav:sync-system-addressbook\".",
