@@ -668,8 +668,8 @@ class SubscriptionService {
 	 * @return array<string, array<string, string>>
 	 */
 	private function getAppsDetails(): array {
-		$enabled = $this->appConfig->searchValues('enabled');
-		$installed = $this->appConfig->searchValues('installed_version');
+		$enabled = $this->appConfig->searchValues('enabled', false, IAppConfig::VALUE_BOOL);
+		$installed = $this->appConfig->searchValues('installed_version', false, IAppConfig::VALUE_STRING);
 
 		/** @var array<string, array<string, string>> $details */
 		$details = [];
