@@ -144,15 +144,15 @@ OC.L10N.register(
     "Log in with a device" : "Aniciar la sesión con un preséu",
     "Login or email" : "Cuenta o direición de corréu electrónicu",
     "Your account is not setup for passwordless login." : "La cuenta nun ta configurada p'aniciar la sesión ensin contraseñes.",
-    "Browser not supported" : "El restolador nun ye compatible",
-    "Passwordless authentication is not supported in your browser." : "El restolador nun ye compatible cola autenticación ensin contraseñes.",
     "Your connection is not secure" : "La conexón nun ye segura",
     "Passwordless authentication is only available over a secure connection." : "L'autenticación ensin contraseñes namás ta disponible per una conexón segura",
+    "Browser not supported" : "El restolador nun ye compatible",
+    "Passwordless authentication is not supported in your browser." : "El restolador nun ye compatible cola autenticación ensin contraseñes.",
     "Reset password" : "Reaniciu de la contraseña",
+    "Back to login" : "Volver al aniciu de la sesión",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si esta cuenta esiste, unvióse un mensaxe pa reaniciar la contraseña a esta cuenta. Si nun recibiesti nengún, verifica la direición o la cuenta, comprueba la carpeta de spam o pidi ayuda a l'alministración.",
     "Couldn't send reset email. Please contact your administrator." : "Nun se pudo unviar el mensaxe de reaniciu. Ponte en contautu cola alministración.",
     "Password cannot be changed. Please contact your administrator." : "Nun se pue camudar la contraseña. Ponte en contautu cola alministración.",
-    "Back to login" : "Volver al aniciu de la sesión",
     "New password" : "Contraseña nueva",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Los ficheros tán cifraos. Nun va haber forma de recuperalos dempués de reafitar la contraseña. Si nun sabes qué facer, ponte en contautu cola alministración enantes de siguir. ¿De xuru que quies siguir?",
     "I know what I'm doing" : "Sé lo que faigo",
@@ -196,6 +196,25 @@ OC.L10N.register(
     "Login form is disabled." : "El formulariu p'aniciar la sesión ta desactiváu.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulariu p'aniciar la sesión de Nextcloud ta desactiváu. Usa otra opción p'aniciar la sesión si ta disponible o ponte en contautu cola alministración.",
     "More actions" : "Más aiciones",
+    "Security warning" : "Alvertencia de seguranza",
+    "Storage & database" : "Almacenamientu y base de datos",
+    "Data folder" : "Carpeta de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Instala y activa los módulos PHP adicionales pa escoyer otros tipos de bases de datos.",
+    "For more details check out the documentation." : "Pa consiguir más detalles, revisa la documentación.",
+    "Performance warning" : "Alvertencia tocante al rindimientu",
+    "You chose SQLite as database." : "Escoyesti SQLite como base de datos.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite habría usase namás pa instancies mínimes y de desendolcu. Pa sirvidores en producción aconseyamos usar otru backend de base de datos.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si uses ficheros pa la sincronización de ficheros, l'usu de SQLite nun ye nada aconseyable.",
+    "Database user" : "Usuariu de la base de datos",
+    "Database password" : "Contraseña de la base de datos",
+    "Database name" : "Nome de la base de datos",
+    "Database tablespace" : "Espaciu de tabla de la base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifica'l númberu de puertu xunto col nome del agospiador (por exemplu, localhost:5432)",
+    "Database host" : "Agospiador de la base de datos",
+    "Installing …" : "Instalando…",
+    "Install" : "Instalar",
+    "Need help?" : "¿Precises ayuda?",
+    "See the documentation" : "Mira la documentación",
     "{name} version {version} and above" : "{name} versión {version} y superior",
     "This browser is not supported" : "Esti restolador nun ye compatible",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "El restolador nun ye compatible. Anuévalu o instala una versión compatible.",
@@ -236,11 +255,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escribi pa buscar proyeutos esistentes",
     "New in" : "Novedá en",
     "View changelog" : "Ver el rexistru de cambeos",
-    "Very weak password" : "La contraseña ye mui poco segura",
-    "Weak password" : "La contraseña ye poco segura",
-    "So-so password" : "La contraseña ye normal",
-    "Good password" : "La contraseña ye segura",
-    "Strong password" : "La contraseña ye mui segura",
     "No action available" : "Nun hai nenguna aición disponible",
     "Error fetching contact actions" : "Hebo un error al dir en cata de les aiciones del contautu",
     "Close \"{dialogTitle}\" dialog" : "Zarrar el diálogu «{dialogTitle}»",
@@ -276,31 +290,6 @@ OC.L10N.register(
     "File: %s" : "Ficheru: %s",
     "Line: %s" : "Llinia: %s",
     "Trace" : "Rastru",
-    "Security warning" : "Alvertencia de seguranza",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet porque'l ficheru .htaccess nun funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pa consiguir más información tocante a cómo configurar afayadizamente'l sirvidor, mira la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
-    "Show password" : "Amosar la contraseña",
-    "Toggle password visibility" : "Alternar la visibilidá de la contraseña",
-    "Storage & database" : "Almacenamientu y base de datos",
-    "Data folder" : "Carpeta de datos",
-    "Configure the database" : "Configurar la base de datos",
-    "Only %s is available." : "Namás hai disponible %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Instala y activa los módulos PHP adicionales pa escoyer otros tipos de bases de datos.",
-    "For more details check out the documentation." : "Pa consiguir más detalles, revisa la documentación.",
-    "Database account" : "Cuenta de la base de datos",
-    "Database password" : "Contraseña de la base de datos",
-    "Database name" : "Nome de la base de datos",
-    "Database tablespace" : "Espaciu de tabla de la base de datos",
-    "Database host" : "Agospiador de la base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Especifica'l númberu de puertu xunto col nome del agospiador (por exemplu, localhost:5432)",
-    "Performance warning" : "Alvertencia tocante al rindimientu",
-    "You chose SQLite as database." : "Escoyesti SQLite como base de datos.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite habría usase namás pa instancies mínimes y de desendolcu. Pa sirvidores en producción aconseyamos usar otru backend de base de datos.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si uses ficheros pa la sincronización de ficheros, l'usu de SQLite nun ye nada aconseyable.",
-    "Install" : "Instalar",
-    "Installing …" : "Instalando…",
-    "Need help?" : "¿Precises ayuda?",
-    "See the documentation" : "Mira la documentación",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Paez que tentes de volver instalar Nextcloud. Por embargu, falta'l ficheru «CAN_INSTALL» nel ficheru de configuración. Crealu pa siguir.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nun se pudo quitar el ficheru «CAN_INSTALL» de la carpeta de configuración. Quítalu manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "L'aplicación rique JavaScript pa funcionar correutamente. {linkstart}Activa JavaScript{linkend} y volvi cargar la páxina.",
@@ -369,7 +358,19 @@ OC.L10N.register(
     "Edit Profile" : "Editar el perfil",
     "The headline and about sections will show up here" : "Equí apaecen la testera y les seiciones d'información",
     "Error loading message template: {error}" : "Hebo un error al cargar la plantía del mensaxe: {error}",
+    "Very weak password" : "La contraseña ye mui poco segura",
+    "Weak password" : "La contraseña ye poco segura",
+    "So-so password" : "La contraseña ye normal",
+    "Good password" : "La contraseña ye segura",
+    "Strong password" : "La contraseña ye mui segura",
     "Profile not found" : "Nun s'atopó'l perfil",
-    "The profile does not exist." : "El perfil nun esiste."
+    "The profile does not exist." : "El perfil nun esiste.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ye probable que'l to direutoriu de datos y los ficheros seyan accesibles dende internet porque'l ficheru .htaccess nun funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pa consiguir más información tocante a cómo configurar afayadizamente'l sirvidor, mira la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
+    "Show password" : "Amosar la contraseña",
+    "Toggle password visibility" : "Alternar la visibilidá de la contraseña",
+    "Configure the database" : "Configurar la base de datos",
+    "Only %s is available." : "Namás hai disponible %s.",
+    "Database account" : "Cuenta de la base de datos"
 },
 "nplurals=2; plural=(n != 1);");
