@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Přihlásit se pomocí zařízení",
     "Login or email" : "Přihlašovací jméno nebo e-mail",
     "Your account is not setup for passwordless login." : "Váš účet nemá nastavené přihlašování se bez hesla.",
-    "Browser not supported" : "Prohlížeč není podporován",
-    "Passwordless authentication is not supported in your browser." : "Přihlašování se bez hesla není ve vámi používaném prohlížeči podporováno.",
     "Your connection is not secure" : "Vaše připojení není zabezpečené",
     "Passwordless authentication is only available over a secure connection." : "Ověření se bez hesla je k dispozici pouze přes zabezpečené připojení.",
+    "Browser not supported" : "Prohlížeč není podporován",
+    "Passwordless authentication is not supported in your browser." : "Přihlašování se bez hesla není ve vámi používaném prohlížeči podporováno.",
     "Reset password" : "Resetovat heslo",
+    "Back to login" : "Zpět na přihlášení",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Pokud tento účet existuje, byla na jeho e-mailovou adresu odeslána zpráva s pokyny pro znovunastavení hesla. Pokud jste ji neobdrželi, zkontrolujte správnost zadání e-mailové adresy a/nebo přihlašovacího jména, dále se podívejte také do složek s nevyžádanou poštou (spam). Případně požádejte svého místního správce o pomoc.",
     "Couldn't send reset email. Please contact your administrator." : "Nepodařilo se odeslat e-mail pro změnu hesla. Obraťte se na správce.",
     "Password cannot be changed. Please contact your administrator." : "Heslo nelze změnit. Obraťte se na svého správce systému.",
-    "Back to login" : "Zpět na přihlášení",
     "New password" : "Nové heslo",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vaše soubory jsou šifrované. Vyresetováním hesla nebude způsob, jak získat vaše data zpět. Pokud nevíte, co dělat, nepokračujte a obraťte se na svého správce. Opravdu chcete pokračovat?",
     "I know what I'm doing" : "Vím co dělám",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "Formulář pro přihlášení je vypnut",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Přihlašovací formulář je v Nextcloud vypnutý. Použijte jinou možnost přihlášení nebo se obraťte na svého správce.",
     "More actions" : "Další akce",
+    "Password is too weak" : "Heslo je příliš snadno prolomitelné",
+    "Password is weak" : "Heslo je snadno prolomitelné",
+    "Password is average" : "Heslo je postačující",
+    "Password is strong" : "Heslo je odolné",
+    "Password is very strong" : "Heslo je velmi odolné",
+    "Password is extremely strong" : "Heslo je extrémně odolné",
+    "Unknown password strength" : "Neznámá odolnost hesla",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor <code>.htaccess</code> nefunguje.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informace o tom, jak správně nastavit váš server, naleznete v {linkStart}dokumentaci{linkEnd}",
+    "Autoconfig file detected" : "Zjištěn soubor s automatického nastavení",
+    "The setup form below is pre-filled with the values from the config file." : "Níže uvedený formulář nastavení je předvyplněný hodnotami ze souboru s nastaveními.",
+    "Security warning" : "Varování ohledně zabezpečení",
+    "Create administration account" : "Vytvořit účet pro správnu",
+    "Administration account name" : "Název účtu pro správu",
+    "Administration account password" : "Heslo k účtu pro správu",
+    "Storage & database" : "Úložiště a databáze",
+    "Data folder" : "Složka s daty",
+    "Database configuration" : "Nastavení databáze",
+    "Only {firstAndOnlyDatabase} is available." : "K dispozici je pouze {firstAndOnlyDatabase}.",
+    "Install and activate additional PHP modules to choose other database types." : "Pokud chcete vybrat jiné typy databáze, je třeba nainstalovat a povolit dodatečné PHP moduly.",
+    "For more details check out the documentation." : "Podrobnosti naleznete v dokumentaci.",
+    "Performance warning" : "Varování ohledně výkonu",
+    "You chose SQLite as database." : "Zvolíte jako databázi SQLite.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by mělo být použito pouze pro instance, které slouží jen pro vývoj nebo ty obhospodařující opravdu velmi málo dat a uživatelů. Pro jakékoli produkční použití doporučujeme použít robustnější databázové řešení.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Pokud používáte klienty pro synchronizaci souborů, je použití SQLite silně nedoporučeno.",
+    "Database user" : "Uživatel databáze",
+    "Database password" : "Heslo do databáze",
+    "Database name" : "Název databáze",
+    "Database tablespace" : "Tabulkový prostor databáze",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
+    "Database host" : "Stroj na kterém se nachází databáze",
+    "localhost" : "localhost",
+    "Installing …" : "Instalace…",
+    "Install" : "Nainstalovat",
+    "Need help?" : "Potřebujete nápovědu?",
+    "See the documentation" : "Viz dokumentace",
     "{name} version {version} and above" : "{name} verze {version} a novější",
     "This browser is not supported" : "Tento prohlížeč není podporován",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Psaním vyhledávejte existující projekty",
     "New in" : "Nové v",
     "View changelog" : "Zobrazit souhrn změn",
-    "Very weak password" : "Velmi snadno prolomitelné heslo",
-    "Weak password" : "Snadno prolomitelné heslo",
-    "So-so password" : "Ještě použitelné heslo",
-    "Good password" : "Dobré heslo",
-    "Strong password" : "Odolné heslo",
     "No action available" : "Není dostupná žádná akce",
     "Error fetching contact actions" : "Chyba při získávání akcí kontaktů",
     "Close \"{dialogTitle}\" dialog" : "Zavřít „{dialogTitle}“ dialog",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "Soubor: %s",
     "Line: %s" : "Řádek: %s",
     "Trace" : "Trace",
-    "Security warning" : "Varování ohledně zabezpečení",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
-    "<strong>Create an admin account</strong>" : "</strong>Vytvořit účet správce</strong>",
-    "New admin account name" : "Název účtu nového správce",
-    "New admin password" : "Heslo nového správce",
-    "Show password" : "Zobrazit heslo",
-    "Toggle password visibility" : "Přepnout viditelnost hesla",
-    "Storage & database" : "Úložiště a databáze",
-    "Data folder" : "Složka s daty",
-    "Configure the database" : "Nastavit databázi",
-    "Only %s is available." : "Je k dispozici pouze %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Pokud chcete vybrat jiné typy databáze, je třeba nainstalovat a povolit dodatečné PHP moduly.",
-    "For more details check out the documentation." : "Podrobnosti naleznete v dokumentaci.",
-    "Database account" : "Účet do databáze",
-    "Database password" : "Heslo do databáze",
-    "Database name" : "Název databáze",
-    "Database tablespace" : "Tabulkový prostor databáze",
-    "Database host" : "Stroj na kterém se nachází databáze",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Zadejte port spolu s názvem hostitele (t. j., localhost:5432).",
-    "Performance warning" : "Varování ohledně výkonu",
-    "You chose SQLite as database." : "Zvolíte jako databázi SQLite.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by mělo být použito pouze pro instance, které slouží jen pro vývoj nebo ty obhospodařující opravdu velmi málo dat a uživatelů. Pro jakékoli produkční použití doporučujeme použít robustnější databázové řešení.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Pokud používáte klienty pro synchronizaci souborů, je použití SQLite silně nedoporučeno.",
-    "Install" : "Nainstalovat",
-    "Installing …" : "Instalace…",
-    "Need help?" : "Potřebujete nápovědu?",
-    "See the documentation" : "Viz dokumentace",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Zdá se, že se pokoušíte přeinstalovat svou instanci NextCloud. Nicméně ve vašem adresáři s nastaveními chybí soubor CAN_INSTALL. Aby bylo možné pokračovat, takový tam vytvořte.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nedaří se ze složky s nastaveními odstranit soubor CAN_INSTALL. Odstraňte ho proto ručně.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Tato aplikace potřebuje pro správnou funkčnost JavaScript. {linkstart}Povolte ho{linkend} a stránku znovu načtěte.",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "Upravit profil",
     "The headline and about sections will show up here" : "Nadpis a sekce o uživatelích se zobrazí zde",
     "Error loading message template: {error}" : "Chyba při načítání šablony zprávy: {error}",
+    "Very weak password" : "Velmi snadno prolomitelné heslo",
+    "Weak password" : "Snadno prolomitelné heslo",
+    "So-so password" : "Ještě použitelné heslo",
+    "Good password" : "Dobré heslo",
+    "Strong password" : "Odolné heslo",
     "Profile not found" : "Profil nenalezen",
-    "The profile does not exist." : "Profil neexistuje."
+    "The profile does not exist." : "Profil neexistuje.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Váš adresář data a soubory jsou přístupné z Internetu, protože soubor .htaccess nefunguje.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informace o tom, jak správně nastavit svůj server, naleznete v <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaci</a>.",
+    "<strong>Create an admin account</strong>" : "</strong>Vytvořit účet správce</strong>",
+    "New admin account name" : "Název účtu nového správce",
+    "New admin password" : "Heslo nového správce",
+    "Show password" : "Zobrazit heslo",
+    "Toggle password visibility" : "Přepnout viditelnost hesla",
+    "Configure the database" : "Nastavit databázi",
+    "Only %s is available." : "Je k dispozici pouze %s.",
+    "Database account" : "Účet do databáze"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
