@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Iniciar sesión con dispositivo",
     "Login or email" : "Nombre de usuario o correo electrónico",
     "Your account is not setup for passwordless login." : "Tu cuenta no está configurada para iniciar sesión sin contraseña",
-    "Browser not supported" : "Navegador no compatible",
-    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
     "Your connection is not secure" : "Tu conexión no es segura",
     "Passwordless authentication is only available over a secure connection." : "La autenticación sin contraseña solo está disponible bajo una conexión segura.",
+    "Browser not supported" : "Navegador no compatible",
+    "Passwordless authentication is not supported in your browser." : "La autenticación sin contraseña no está soportada en tu navegador.",
     "Reset password" : "Restablecer contraseña",
+    "Back to login" : "Regresar al inicio de sesión",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si la cuenta existe, se ha enviado un mensaje para reestablecer la contraseña a su dirección de correo. Si no lo recibe, verifique su dirección de correo y/o usuario, compruebe sus carpetas de correo basura o solicite ayuda a su administración.",
     "Couldn't send reset email. Please contact your administrator." : "No fue posible enviar el correo de restauración. Por favor contacta a tu adminsitrador. ",
     "Password cannot be changed. Please contact your administrator." : "La contraseña no puede ser cambiada. Por favor, contacte con su administrador.",
-    "Back to login" : "Regresar al inicio de sesión",
     "New password" : "Nueva contraseña",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Sus archivos están encriptados. No habrá forma de recuperar sus datos después de restablecer su contraseña. Si no está seguro de qué hacer, contacte a su administrador antes de continuar. ¿Realmente desea continuar?",
     "I know what I'm doing" : "Sé lo que estoy haciendo",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "La página de inicio de sesión está deshabilitada.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "El formulario de inicio de sesión de Nextcloud está deshabilitado. Use otro medio de inicio de sesión disponible o contacte a su administración.",
     "More actions" : "Más acciones",
+    "Security warning" : "Advertencia de seguridad",
+    "Storage & database" : "Almacenamiento & base de datos",
+    "Data folder" : "Carpeta de datos",
+    "Install and activate additional PHP modules to choose other database types." : "Instala y activa módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
+    "For more details check out the documentation." : "Por favor consulta la documentación para más detalles. ",
+    "Performance warning" : "Advertencia de desempeño",
+    "You chose SQLite as database." : "Eligió SQLite como base de datos.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sólo debe usarse para instancias mínimas y de desarrollo. Para producción, recomendamos un motor de base de datos diferente.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para sincronizar archivos, el uso de SQLite se desaconseja encarecidamente.",
+    "Database user" : "Usuario de la base de datos",
+    "Database password" : "Contraseña de la base de datos",
+    "Database name" : "Nombre de la base de datos",
+    "Database tablespace" : "Espacio de tablas en la base de datos",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
+    "Database host" : "Servidor de base de datos",
+    "Installing …" : "Instalando ...",
+    "Install" : "Instalar",
+    "Need help?" : "¿Necesitas ayuda?",
+    "See the documentation" : "Ver la documentación",
     "{name} version {version} and above" : "{name} versión {version} y superior",
     "This browser is not supported" : "Este navegador no está soportado",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navegador no está soportado. Por favor actualícelo a una versión más nueva o una soportada.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escriba para buscar proyectos existentes",
     "New in" : "Nuevo en",
     "View changelog" : "Ver el registro de cambios",
-    "Very weak password" : "Contraseña muy débil",
-    "Weak password" : "Contraseña débil",
-    "So-so password" : "Contraseña aceptable",
-    "Good password" : "Buena contraseña",
-    "Strong password" : "Contraseña fuerte",
     "No action available" : "No hay acciones disponibles",
     "Error fetching contact actions" : "Se presentó un error al traer las acciónes de contatos",
     "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
@@ -289,31 +303,6 @@ OC.L10N.register(
     "File: %s" : "Archivo: %s",
     "Line: %s" : "Línea: %s",
     "Trace" : "Rastrear",
-    "Security warning" : "Advertencia de seguridad",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para más información de como configurar correctaemente tu servidor, por favor consulta la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
-    "Show password" : "Mostrar contraseña",
-    "Toggle password visibility" : "Alternar visibilidad de la contraseña",
-    "Storage & database" : "Almacenamiento & base de datos",
-    "Data folder" : "Carpeta de datos",
-    "Configure the database" : "Configurar la base de datos",
-    "Only %s is available." : "Sólo %s está disponible.",
-    "Install and activate additional PHP modules to choose other database types." : "Instala y activa módulos adicionales de PHP para seleccionar otros tipos de bases de datos. ",
-    "For more details check out the documentation." : "Por favor consulta la documentación para más detalles. ",
-    "Database account" : "Cuenta de la base de datos",
-    "Database password" : "Contraseña de la base de datos",
-    "Database name" : "Nombre de la base de datos",
-    "Database tablespace" : "Espacio de tablas en la base de datos",
-    "Database host" : "Servidor de base de datos",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifica el número de puerto así como el nombre del servidor (ejem., localhost:5432).",
-    "Performance warning" : "Advertencia de desempeño",
-    "You chose SQLite as database." : "Eligió SQLite como base de datos.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sólo debe usarse para instancias mínimas y de desarrollo. Para producción, recomendamos un motor de base de datos diferente.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para sincronizar archivos, el uso de SQLite se desaconseja encarecidamente.",
-    "Install" : "Instalar",
-    "Installing …" : "Instalando ...",
-    "Need help?" : "¿Necesitas ayuda?",
-    "See the documentation" : "Ver la documentación",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Parece que está intentando reinstalar Nextcloud. Sin embargo, falta el archivo CAN_INSTALL en el directorio de configuración. Por favor, cree el archivo CAN_INSTALL en la carpeta de configuración para continuar.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "No se pudo eliminar CAN_INSTALL de la carpeta de configuración. Por favor, elimine este archivo manualmente.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere de JavaScript para su correcta operación. Por favor {linkstart}habilita JavaScript{linkend} y vuelve a cargar la página. ",
@@ -382,7 +371,19 @@ OC.L10N.register(
     "Edit Profile" : "Editar perfil",
     "The headline and about sections will show up here" : "El encabezado y la sección Acerca de aparecerán aquí",
     "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
+    "Very weak password" : "Contraseña muy débil",
+    "Weak password" : "Contraseña débil",
+    "So-so password" : "Contraseña aceptable",
+    "Good password" : "Buena contraseña",
+    "Strong password" : "Contraseña fuerte",
     "Profile not found" : "Perfil no encontrado",
-    "The profile does not exist." : "El perfil no existe."
+    "The profile does not exist." : "El perfil no existe.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Tu directorio de datos y sus archivos probablemente sean accesibles desde Internet ya que el archivo .htaccess no funciona.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para más información de como configurar correctaemente tu servidor, por favor consulta la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
+    "Show password" : "Mostrar contraseña",
+    "Toggle password visibility" : "Alternar visibilidad de la contraseña",
+    "Configure the database" : "Configurar la base de datos",
+    "Only %s is available." : "Sólo %s está disponible.",
+    "Database account" : "Cuenta de la base de datos"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
