@@ -88,14 +88,14 @@ OC.L10N.register(
     "Password" : "Parool",
     "Log in with a device" : "Logi sisse seadmega",
     "Your account is not setup for passwordless login." : "Su konto ei ole seadistatud paroolivaba sisenemise jaoks.",
-    "Browser not supported" : "Brauser pole toetatud",
-    "Passwordless authentication is not supported in your browser." : "Sinu brauser ei toeta paroolivaba sisenemist.",
     "Your connection is not secure" : "Ühendus ei ole turvaline",
     "Passwordless authentication is only available over a secure connection." : "Paroolivaba sisenemine on saadaval ainult üle turvalise ühenduse.",
+    "Browser not supported" : "Brauser pole toetatud",
+    "Passwordless authentication is not supported in your browser." : "Sinu brauser ei toeta paroolivaba sisenemist.",
     "Reset password" : "Lähtesta parool",
+    "Back to login" : "Tagasi sisse logima",
     "Couldn't send reset email. Please contact your administrator." : "Ei suutnud lähtestada e-maili. Palun võta ühendust administraatoriga.",
     "Password cannot be changed. Please contact your administrator." : "Parooli ei saa muuta. Palun võta ühendust administraatoriga.",
-    "Back to login" : "Tagasi sisse logima",
     "New password" : "Uus parool",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Su failid on krüpteeritud. Pärast parooli lähtestamist ei ole mingit võimalust su andmeid tagasi saada. Kui sa pole kindel, mida teha, võta palun ühendust administraatoriga. Kas soovid kindlasti jätkata?",
     "I know what I'm doing" : "Ma tean, mida teen",
@@ -129,6 +129,22 @@ OC.L10N.register(
     "Back to login form" : "Tagasi sisselogimise lehele",
     "Back" : "Tagasi",
     "Login form is disabled." : "Sisselogimise leht on keelatud.",
+    "Security warning" : "Turvahoiatus",
+    "Storage & database" : "Andmehoidla ja andmebaas",
+    "Data folder" : "Andmekaust",
+    "Install and activate additional PHP modules to choose other database types." : "Paigalda ja aktiveeri täiendavaid PHP mooduleid, et teisi andmebaasi tüüpe valida.",
+    "For more details check out the documentation." : "Lisainfot vaata dokumentatsioonist.",
+    "Performance warning" : "Jõudluse hoiatus",
+    "You chose SQLite as database." : "Sa valisid SQLite andmebaasi.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sobib kasutamiseks ainult arenduseks ja väikesemahulistes serverites. Toodangu jaoks soovitame teist andmebaasilahendust.",
+    "Database user" : "Andmebaasi kasutaja",
+    "Database password" : "Andmebaasi parool",
+    "Database name" : "Andmebaasi nimi",
+    "Database tablespace" : "Andmebaasi tabeliruum",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Palun sisesta hostinimega koos pordi number (nt. localhost:5432).",
+    "Database host" : "Andmebaasi host",
+    "Need help?" : "Vajad abi?",
+    "See the documentation" : "Vaata dokumentatsiooni",
     "{name} version {version} and above" : "{name} versioon {version} ja uuemad",
     "This browser is not supported" : "See brauser pole toetatu",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Sinu brauser ei ole toetatud. Palun uuenda see uuema versiooni peale või vaheta toetatud brauseri vastu.",
@@ -160,11 +176,6 @@ OC.L10N.register(
     "Rename project" : "Nimeta projekt ümber",
     "Failed to rename the project" : "Projekti ümbernimetamine ebaõnnestus",
     "Failed to create a project" : "Projekti loomine ebaõnnestus",
-    "Very weak password" : "Väga nõrk parool",
-    "Weak password" : "Nõrk parool",
-    "So-so password" : "Enam-vähem sobiv parool",
-    "Good password" : "Hea parool",
-    "Strong password" : "Väga hea parool",
     "No action available" : "Ühtegi tegevust pole saadaval",
     "Error fetching contact actions" : "Viga kontakti toimingute laadimisel",
     "Non-existing tag #{tag}" : "Olematu silt #{tag}",
@@ -196,27 +207,6 @@ OC.L10N.register(
     "File: %s" : "Fail: %s",
     "Line: %s" : "Rida: %s",
     "Trace" : "Jälg",
-    "Security warning" : "Turvahoiatus",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmekataloog ja failid on tõenäoliselt internetist vabalt ligipääsetavad, kuna .htaccess fail ei toimi.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Serveri õigeks seadistamiseks leiad infot <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentatsioonist</a>.",
-    "Show password" : "Näita parooli",
-    "Toggle password visibility" : "Lülita parooli nähtavust",
-    "Storage & database" : "Andmehoidla ja andmebaas",
-    "Data folder" : "Andmekaust",
-    "Configure the database" : "Seadista andmebaas",
-    "Only %s is available." : "Ainult %s on saadaval.",
-    "Install and activate additional PHP modules to choose other database types." : "Paigalda ja aktiveeri täiendavaid PHP mooduleid, et teisi andmebaasi tüüpe valida.",
-    "For more details check out the documentation." : "Lisainfot vaata dokumentatsioonist.",
-    "Database password" : "Andmebaasi parool",
-    "Database name" : "Andmebaasi nimi",
-    "Database tablespace" : "Andmebaasi tabeliruum",
-    "Database host" : "Andmebaasi host",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Palun sisesta hostinimega koos pordi number (nt. localhost:5432).",
-    "Performance warning" : "Jõudluse hoiatus",
-    "You chose SQLite as database." : "Sa valisid SQLite andmebaasi.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sobib kasutamiseks ainult arenduseks ja väikesemahulistes serverites. Toodangu jaoks soovitame teist andmebaasilahendust.",
-    "Need help?" : "Vajad abi?",
-    "See the documentation" : "Vaata dokumentatsiooni",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "See rakendus vajab toimimiseks JavaScripti. Palun {linkstart}luba JavaScript{linkend} ning laadi see leht uuesti.",
     "Go to %s" : "Mine %s",
     "Connect to your account" : "Ühenda oma konto",
@@ -264,7 +254,18 @@ OC.L10N.register(
     "Error opening the user status modal, try hard refreshing the page" : "Kasutaja staatuse modaaldialoogi avamine ebaõnnestus, proovi lehte värskendada",
     "Edit Profile" : "Muuda profiili",
     "Error loading message template: {error}" : "Viga sõnumi malli laadimisel: {error}",
+    "Very weak password" : "Väga nõrk parool",
+    "Weak password" : "Nõrk parool",
+    "So-so password" : "Enam-vähem sobiv parool",
+    "Good password" : "Hea parool",
+    "Strong password" : "Väga hea parool",
     "Profile not found" : "Profiili ei leitud",
-    "The profile does not exist." : "Profiili ei eksisteeri"
+    "The profile does not exist." : "Profiili ei eksisteeri",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmekataloog ja failid on tõenäoliselt internetist vabalt ligipääsetavad, kuna .htaccess fail ei toimi.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Serveri õigeks seadistamiseks leiad infot <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentatsioonist</a>.",
+    "Show password" : "Näita parooli",
+    "Toggle password visibility" : "Lülita parooli nähtavust",
+    "Configure the database" : "Seadista andmebaas",
+    "Only %s is available." : "Ainult %s on saadaval."
 },
 "nplurals=2; plural=(n != 1);");
