@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Logáil isteach le gléas",
     "Login or email" : "Logáil isteach nó ríomhphost",
     "Your account is not setup for passwordless login." : "Níl do chuntas socraithe le haghaidh logáil isteach gan pasfhocal.",
-    "Browser not supported" : "Ní thacaítear leis an mbrabhsálaí",
-    "Passwordless authentication is not supported in your browser." : "Ní thacaítear le fíordheimhniú gan pasfhocal i do bhrabhsálaí.",
     "Your connection is not secure" : "Níl do nasc slán",
     "Passwordless authentication is only available over a secure connection." : "Níl fíordheimhniú gan pasfhocal ar fáil ach thar nasc slán.",
+    "Browser not supported" : "Ní thacaítear leis an mbrabhsálaí",
+    "Passwordless authentication is not supported in your browser." : "Ní thacaítear le fíordheimhniú gan pasfhocal i do bhrabhsálaí.",
     "Reset password" : "Athshocraigh pasfhocal",
+    "Back to login" : "Ar ais chuig logáil isteach",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Má tá an cuntas seo ann, tá teachtaireacht athshocraithe pasfhocail seolta chuig a sheoladh ríomhphoist. Mura bhfaigheann tú é, fíoraigh do sheoladh ríomhphoist agus/nó Logáil Isteach, seiceáil d’fhillteáin turscair/dramhphoist nó iarr cabhair ar do riarachán áitiúil.",
     "Couldn't send reset email. Please contact your administrator." : "Níorbh fhéidir ríomhphost athshocraithe a sheoladh. Déan teagmháil le do riarthóir le do thoil.",
     "Password cannot be changed. Please contact your administrator." : "Ní féidir pasfhocal a athrú. Déan teagmháil le do riarthóir.",
-    "Back to login" : "Ar ais chuig logáil isteach",
     "New password" : "Pasfhocal Nua",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tá do chuid comhad criptithe. Ní bheidh aon bhealach chun do shonraí a fháil ar ais tar éis do phasfhocal a athshocrú. Mura bhfuil tú cinnte cad atá le déanamh, déan teagmháil le do riarthóir sula leanann tú ar aghaidh. Ar mhaith leat leanúint ar aghaidh i ndáiríre?",
     "I know what I'm doing" : "Tá a fhios agam cad atá á dhéanamh agam",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "Tá an fhoirm logáil isteach díchumasaithe.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Tá foirm logáil isteach Nextcloud díchumasaithe. Úsáid rogha logáil isteach eile má tá sé ar fáil nó déan teagmháil le do lucht riaracháin.",
     "More actions" : "Tuilleadh gníomhartha",
+    "Password is too weak" : "Tá pasfhocal ró-lag",
+    "Password is weak" : "Tá pasfhocal lag",
+    "Password is average" : "Is pasfhocal meánach",
+    "Password is strong" : "Tá pasfhocal láidir",
+    "Password is very strong" : "Tá pasfhocal an-láidir",
+    "Password is extremely strong" : "Tá pasfhocal thar a bheith láidir",
+    "Unknown password strength" : "Neart phasfhocal anaithnid",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Is dócha go bhfuil do eolaire sonraí agus comhaid inrochtana ón idirlíon toisc nach n-oibríonn an comhad <code>.htaccess</code>.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Chun eolas a fháil ar conas do fhreastalaí a chumrú i gceart, {linkStart}féach ar an doiciméadú{linkEnd}",
+    "Autoconfig file detected" : "Braitheadh ​​comhad Autoconfig",
+    "The setup form below is pre-filled with the values from the config file." : "Tá an fhoirm socraithe thíos réamhlíonta leis na luachanna ón gcomhad cumraíochta.",
+    "Security warning" : "Rabhadh slándála",
+    "Create administration account" : "Cruthaigh cuntas riaracháin",
+    "Administration account name" : "Ainm an chuntais riaracháin",
+    "Administration account password" : "Pasfhocal cuntas riaracháin",
+    "Storage & database" : "Stóráil agus bunachar sonraí",
+    "Data folder" : "Fillteán sonraí",
+    "Database configuration" : "Cumraíocht bunachar sonraí",
+    "Only {firstAndOnlyDatabase} is available." : "Níl ach {firstAndOnlyDatabase} ar fáil.",
+    "Install and activate additional PHP modules to choose other database types." : "Suiteáil agus gníomhachtaigh modúil PHP breise chun cineálacha bunachar sonraí eile a roghnú.",
+    "For more details check out the documentation." : "Le haghaidh tuilleadh sonraí féach ar an doiciméadú.",
+    "Performance warning" : "Rabhadh feidhmíochta",
+    "You chose SQLite as database." : "Roghnaigh tú SQLite mar bhunachar sonraí.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Níor cheart SQLite a úsáid ach amháin le haghaidh cásanna íosta agus forbartha. Le haghaidh táirgeadh molaimid inneall bunachar sonraí difriúil.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Má úsáideann tú cliaint chun comhaid a shioncronú, ní miste go mór úsáid SQLite.",
+    "Database user" : "Úsáideoir bunachar sonraí",
+    "Database password" : "Pasfhocal bunachar sonraí",
+    "Database name" : "Ainm bunachar sonraí",
+    "Database tablespace" : "Bunachar sonraí spás tábla",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Sonraigh le do thoil uimhir an phoirt mar aon le hainm an óstaigh (m.sh., localhost: 5432).",
+    "Database host" : "Óstach bunachar sonraí",
+    "localhost" : "áitiúil-óstach",
+    "Installing …" : "Suiteáil…",
+    "Install" : "Suiteáil",
+    "Need help?" : "Teastaionn Cabhair?",
+    "See the documentation" : "Féach ar an doiciméadú",
     "{name} version {version} and above" : "{name} leagan {version} agus os a chionn",
     "This browser is not supported" : "Ní thacaítear leis an mbrabhsálaí seo",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ní thacaítear le do bhrabhsálaí. Uasghrádaigh go leagan níos nuaí nó go leagan a dtacaítear leis le do thoil.",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Clóscríobh chun tionscadail atá ann cheana a chuardach",
     "New in" : "Nua isteach",
     "View changelog" : "Féach ar loga na n-athruithe",
-    "Very weak password" : "Pasfhocal an-lag",
-    "Weak password" : "Pasfhocal lag",
-    "So-so password" : "mar sin-sin pasfhocal",
-    "Good password" : "pasfhocal maith",
-    "Strong password" : "Pasfhocal láidir",
     "No action available" : "Níl aon ghníomh ar fáil",
     "Error fetching contact actions" : "Earráid agus gníomhartha teagmhála á bhfáil",
     "Close \"{dialogTitle}\" dialog" : "Dún dialóg \"{dialogTitle}\".",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "Comhad: %s",
     "Line: %s" : "Líne: %s",
     "Trace" : "Rian",
-    "Security warning" : "Rabhadh slándála",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is dócha go bhfuil do eolaire sonraí agus comhaid inrochtana ón idirlíon toisc nach n-oibríonn an comhad .htaccess.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Chun tuilleadh faisnéise a fháil faoi conas do fhreastalaí a chumrú i gceart, féach ar an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">doiciméad</a>le do thoil. ",
-    "<strong>Create an admin account</strong>" : "<strong>Cruthaigh cuntas riaracháin</strong>",
-    "New admin account name" : "Ainm cuntais riaracháin nua",
-    "New admin password" : "Pasfhocal riarthóir nua",
-    "Show password" : "Taispeáin pasfhocal",
-    "Toggle password visibility" : "Scoránaigh infheictheacht pasfhocail",
-    "Storage & database" : "Stóráil agus bunachar sonraí",
-    "Data folder" : "Fillteán sonraí",
-    "Configure the database" : "Cumraigh an bunachar sonraí",
-    "Only %s is available." : "Níl ach %s ar fáil.",
-    "Install and activate additional PHP modules to choose other database types." : "Suiteáil agus gníomhachtaigh modúil PHP breise chun cineálacha bunachar sonraí eile a roghnú.",
-    "For more details check out the documentation." : "Le haghaidh tuilleadh sonraí féach ar an doiciméadú.",
-    "Database account" : "Cuntas bunachar sonraí",
-    "Database password" : "Pasfhocal bunachar sonraí",
-    "Database name" : "Ainm bunachar sonraí",
-    "Database tablespace" : "Bunachar sonraí spás tábla",
-    "Database host" : "Óstach bunachar sonraí",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Sonraigh le do thoil uimhir an phoirt mar aon le hainm an óstaigh (m.sh., localhost: 5432).",
-    "Performance warning" : "Rabhadh feidhmíochta",
-    "You chose SQLite as database." : "Roghnaigh tú SQLite mar bhunachar sonraí.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Níor cheart SQLite a úsáid ach amháin le haghaidh cásanna íosta agus forbartha. Le haghaidh táirgeadh molaimid inneall bunachar sonraí difriúil.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Má úsáideann tú cliaint chun comhaid a shioncronú, ní miste go mór úsáid SQLite.",
-    "Install" : "Suiteáil",
-    "Installing …" : "Suiteáil…",
-    "Need help?" : "Teastaionn Cabhair?",
-    "See the documentation" : "Féach ar an doiciméadú",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Tá an chuma ar an scéal go bhfuil tú ag iarraidh do Nextcloud a athshuiteáil. Tá an comhad CAN_INSTALL in easnamh ar do chomhadlann cumraíochta áfach. Cruthaigh an comhad CAN_INSTALL i d'fhillteán cumraíochta chun leanúint ar aghaidh le do thoil.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Níorbh fhéidir CAN_INSTALL a bhaint den fhillteán cumraíochta. Bain an comhad seo de láimh le do thoil.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Teastaíonn JavaScript ón bhfeidhmchlár seo chun oibriú ceart. Le do thoil {linkstart}Cumasaigh JavaScript{linkend} agus athlódáil an leathanach le do thoil.",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "Cuir Próifíl in Eagar",
     "The headline and about sections will show up here" : "Taispeánfar an ceannlíne agus na hailt faoi anseo",
     "Error loading message template: {error}" : "Earráid agus teimpléad na teachtaireachta á lódáil: {error}",
+    "Very weak password" : "Pasfhocal an-lag",
+    "Weak password" : "Pasfhocal lag",
+    "So-so password" : "mar sin-sin pasfhocal",
+    "Good password" : "pasfhocal maith",
+    "Strong password" : "Pasfhocal láidir",
     "Profile not found" : "Próifíl gan aimsiú",
-    "The profile does not exist." : "Níl an phróifíl ann."
+    "The profile does not exist." : "Níl an phróifíl ann.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is dócha go bhfuil do eolaire sonraí agus comhaid inrochtana ón idirlíon toisc nach n-oibríonn an comhad .htaccess.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Chun tuilleadh faisnéise a fháil faoi conas do fhreastalaí a chumrú i gceart, féach ar an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">doiciméad</a>le do thoil. ",
+    "<strong>Create an admin account</strong>" : "<strong>Cruthaigh cuntas riaracháin</strong>",
+    "New admin account name" : "Ainm cuntais riaracháin nua",
+    "New admin password" : "Pasfhocal riarthóir nua",
+    "Show password" : "Taispeáin pasfhocal",
+    "Toggle password visibility" : "Scoránaigh infheictheacht pasfhocail",
+    "Configure the database" : "Cumraigh an bunachar sonraí",
+    "Only %s is available." : "Níl ach %s ar fáil.",
+    "Database account" : "Cuntas bunachar sonraí"
 },
 "nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
