@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "기기로 로그인",
     "Login or email" : "로그인 또는 이메일",
     "Your account is not setup for passwordless login." : "당신의 계정은 암호 없이 로그인하도록 설정되지 않았습니다.",
-    "Browser not supported" : "브라우저를 지원하지 않습니다.",
-    "Passwordless authentication is not supported in your browser." : "당신의 브라우저에서 암호 없는 인증을 지원하지 않습니다.",
     "Your connection is not secure" : "당신의 연결이 안전하지 않습니다.",
     "Passwordless authentication is only available over a secure connection." : "암호 없는 인증은 보안 연결에서만 사용할 수 있습니다.",
+    "Browser not supported" : "브라우저를 지원하지 않습니다.",
+    "Passwordless authentication is not supported in your browser." : "당신의 브라우저에서 암호 없는 인증을 지원하지 않습니다.",
     "Reset password" : "암호 재설정",
+    "Back to login" : "로그인으로 돌아가기",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "계정이 존재한다면, 암호 초기화 메시지가 해당 계정의 이메일 주소로 전송됩니다. 만일 메일을 수신하지 못했다면, 이메일 주소 및 계정 이름을 확인하고 스팸 메일 폴더를 확인하십시오. 또는, 가까운 관리자에게 도움을 요청하십시오.",
     "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
     "Password cannot be changed. Please contact your administrator." : "암호를 변경할 수 없습니다. 관리자에게 문의하십시오.",
-    "Back to login" : "로그인으로 돌아가기",
     "New password" : "새 암호",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "내 파일이 암호화되어 있습니다. 암호를 초기화하면 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 시스템 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
     "I know what I'm doing" : "지금 하려는 것을 알고 있습니다",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "로그인 양식이 비활성화 되었습니다.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 로그인 양식이 비활성화 되었습니다. 이용 가능한 다른 방법으로 로그인 하거나, 관리자에게 문의하십시오.",
     "More actions" : "더 많은 동작",
+    "Security warning" : "보안 경고",
+    "Storage & database" : "저장소 및 데이터베이스",
+    "Data folder" : "데이터 폴더",
+    "Install and activate additional PHP modules to choose other database types." : "다른 데이터베이스 종류를 사용하려면 추가 PHP 모듈을 설치 및 활성화하십시오.",
+    "For more details check out the documentation." : "자세한 정보를 보려면 문서를 참고하십시오.",
+    "Performance warning" : "성능 경고",
+    "You chose SQLite as database." : "데이터베이스로 SQLite를 선택하셨습니다.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite는 최소 및 개발 목적의 인스턴스에만 사용하는 것을 추천합니다. 실제 업무에 사용하려면 다른 데이터베이스 백엔드를 사용하십시오.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "만약 파일 동기화 클라이언트를 사용하려고 한다면 SQLite를 사용하지 않는 것이 좋습니다.",
+    "Database user" : "데이터베이스 사용자",
+    "Database password" : "데이터베이스 암호",
+    "Database name" : "데이터베이스 이름",
+    "Database tablespace" : "데이터베이스 테이블 공간",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "호스트 이름과 함께 포트 번호를 지정하십시오(예: localhost:5432)",
+    "Database host" : "데이터베이스 호스트",
+    "Installing …" : "설치중…",
+    "Install" : "설치",
+    "Need help?" : "도움이 필요한가요?",
+    "See the documentation" : "문서 보기",
     "{name} version {version} and above" : "{name}의 {version} 버전 이상",
     "This browser is not supported" : "이 브라우저는 지원되지 않습니다.",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "이 브라우저는 지원되지 않습니다. 새로운 버전 및 지원되는 브라우저로 업그레이드 하세요.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "이미 존재하는 프로젝트를 찾기 위해 입력하세요.",
     "New in" : "새로운 것",
     "View changelog" : "변경 기록 확인",
-    "Very weak password" : "매우 약한 암호",
-    "Weak password" : "약한 암호",
-    "So-so password" : "그저 그런 암호",
-    "Good password" : "좋은 암호",
-    "Strong password" : "강력한 암호",
     "No action available" : "사용할 수 있는 동작 없음",
     "Error fetching contact actions" : "연락처 동작을 가져오는 중 오류 발생",
     "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" 대화 상자 닫기",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "파일: %s",
     "Line: %s" : "줄: %s",
     "Trace" : "추적",
-    "Security warning" : "보안 경고",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수도 있습니다.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "서버를 올바르게 설정하는 방법에 대해서 더 알아보려면 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">문서</a>를 참조하십시오.",
-    "<strong>Create an admin account</strong>" : "<strong>관리자 계정 만들기</strong>",
-    "New admin account name" : "새 관리자 계정 이름",
-    "New admin password" : "새 관리자 비밀번호",
-    "Show password" : "암호 표시",
-    "Toggle password visibility" : "암호 보이기/숨기기",
-    "Storage & database" : "저장소 및 데이터베이스",
-    "Data folder" : "데이터 폴더",
-    "Configure the database" : "데이터베이스 설정",
-    "Only %s is available." : "%s만 사용할 수 있습니다.",
-    "Install and activate additional PHP modules to choose other database types." : "다른 데이터베이스 종류를 사용하려면 추가 PHP 모듈을 설치 및 활성화하십시오.",
-    "For more details check out the documentation." : "자세한 정보를 보려면 문서를 참고하십시오.",
-    "Database account" : "데이터베이스 계정",
-    "Database password" : "데이터베이스 암호",
-    "Database name" : "데이터베이스 이름",
-    "Database tablespace" : "데이터베이스 테이블 공간",
-    "Database host" : "데이터베이스 호스트",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "호스트 이름과 함께 포트 번호를 지정하십시오(예: localhost:5432)",
-    "Performance warning" : "성능 경고",
-    "You chose SQLite as database." : "데이터베이스로 SQLite를 선택하셨습니다.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite는 최소 및 개발 목적의 인스턴스에만 사용하는 것을 추천합니다. 실제 업무에 사용하려면 다른 데이터베이스 백엔드를 사용하십시오.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "만약 파일 동기화 클라이언트를 사용하려고 한다면 SQLite를 사용하지 않는 것이 좋습니다.",
-    "Install" : "설치",
-    "Installing …" : "설치중…",
-    "Need help?" : "도움이 필요한가요?",
-    "See the documentation" : "문서 보기",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloud를 다시 설치하려고 하는 것 같습니다. 그러나 현재 설정 디렉터리에 CAN_INSTALL 파일이 없는 것 같습니다. 계속 진행하려면 설정 폴더에 CAN_INSTALL 폴더를 만드십시오.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "설정 폴더에서 CAN_INSTALL 파일을 삭제할 수 없습니다. 직접 삭제하십시오.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "이 프로그램이 올바르게 작동하려면 자바스크립트가 필요합니다. {linkstart}자바스크립트를 활성화{linkend}한 다음 페이지를 새로 고치십시오.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "프로필 수정",
     "The headline and about sections will show up here" : "표제와 기타 정보가 이곳에 나타납니다.",
     "Error loading message template: {error}" : "메시지 템플릿을 불러오는 중 오류 발생: {error}",
+    "Very weak password" : "매우 약한 암호",
+    "Weak password" : "약한 암호",
+    "So-so password" : "그저 그런 암호",
+    "Good password" : "좋은 암호",
+    "Strong password" : "강력한 암호",
     "Profile not found" : "프로필 찾을 수 없음",
-    "The profile does not exist." : "프로필이 존재하지 않습니다."
+    "The profile does not exist." : "프로필이 존재하지 않습니다.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수도 있습니다.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "서버를 올바르게 설정하는 방법에 대해서 더 알아보려면 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">문서</a>를 참조하십시오.",
+    "<strong>Create an admin account</strong>" : "<strong>관리자 계정 만들기</strong>",
+    "New admin account name" : "새 관리자 계정 이름",
+    "New admin password" : "새 관리자 비밀번호",
+    "Show password" : "암호 표시",
+    "Toggle password visibility" : "암호 보이기/숨기기",
+    "Configure the database" : "데이터베이스 설정",
+    "Only %s is available." : "%s만 사용할 수 있습니다.",
+    "Database account" : "데이터베이스 계정"
 },
 "nplurals=1; plural=0;");
