@@ -51,7 +51,7 @@ OC.L10N.register(
     "Unable to translate" : "Nevar iztulkot",
     "Nextcloud Server" : "Nextcloud Serveris",
     "Some of your link shares have been removed" : "Dažas no Jūsu kopīgotajām saitēm tika noņemtas",
-    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Drošības nepilnības dēļ, mums nācās noņemt dažas no Jūsu kopīgotajām saitēm. Lūdzu, skatiet saiti papildus informācijai.",
+    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Drošības kļūdas dēļ mums nācās noņemt dažas no kopīgotajām saitēm. Lūgums apmeklēt saiti, lai iegūtu vairāk informācijas.",
     "The account limit of this instance is reached." : "Konta ierobežojums šajai instancei ir sasniegts.",
     "Learn more ↗" : "Uzzināt vairāk ↗",
     "Preparing update" : "Sagatavo atjauninājumu",
@@ -135,14 +135,14 @@ OC.L10N.register(
     "Log in with a device" : "Pieteikties ar ierīci",
     "Login or email" : "Lietotājvārds vai e-pasta adrese",
     "Your account is not setup for passwordless login." : "Konts nav iestatīts, lai pieteiktos bez paroles.",
-    "Browser not supported" : "Pārlūkprogramma netiek atbalstīta",
-    "Passwordless authentication is not supported in your browser." : "Pārlūkprogrammā netiek nodrošināta autentifikācija bez paroles",
     "Your connection is not secure" : "Jūsu savienojums nav drošs",
     "Passwordless authentication is only available over a secure connection." : "Autentifikācija bez paroles ir pieejama tikai ar drošu savienojumu.",
+    "Browser not supported" : "Pārlūkprogramma netiek atbalstīta",
+    "Passwordless authentication is not supported in your browser." : "Pārlūkprogrammā netiek nodrošināta autentifikācija bez paroles",
     "Reset password" : "Atiestatīt paroli",
+    "Back to login" : "Atpakaļ uz pieteikšanos",
     "Couldn't send reset email. Please contact your administrator." : "Nevarēja nosūtīt atiestatīšanas e-pasta ziņojumu. Lūgums sazināties ar savu pārvaldītāju.",
     "Password cannot be changed. Please contact your administrator." : "Parole nav nomaināma. Lūgums sazināties ar savu pārvaldītāju.",
-    "Back to login" : "Atpakaļ uz pieteikšanos",
     "New password" : "Jauna parole",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tavas datnes ir šifrētas. Pēc paroles atiestatīšanas nebūs iespējams atgūt datus. Ja nav zināms, kā rīkoties, lūgums pirms turpināšanas sazināties ar pārvaldītāju. Vai tiešām turpināt?",
     "I know what I'm doing" : "Es zinu ko es daru",
@@ -166,6 +166,20 @@ OC.L10N.register(
     "Search" : "Meklēt",
     "Forgot password?" : "Aizmirsta parole?",
     "Back" : "Atpakaļ",
+    "Security warning" : "Drošības brīdinājums",
+    "Storage & database" : "Krātuve & datubāze",
+    "Data folder" : "Datu mape",
+    "Install and activate additional PHP modules to choose other database types." : "Instalējiet un aktivizējiet papildus PHP moduļus lai izvēlētos citus datubāžu tipus.",
+    "For more details check out the documentation." : "Vairāk informācijas ir meklējama dokumentācijā.",
+    "Performance warning" : "Veiktspējas brīdinājums",
+    "Database user" : "Datubāzes lietotājs",
+    "Database password" : "Datubāzes parole",
+    "Database name" : "Datubāzes nosaukums",
+    "Database tablespace" : "Datubāzes tabulas telpa",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lūdzu, norādiet porta numuru kopā ar resursdatora nosaukumu (piemēram, localhost: 5432).",
+    "Database host" : "Datubāzes serveris",
+    "Need help?" : "Vajadzīga palīdzība?",
+    "See the documentation" : "Skatiet dokumentāciju",
     "Choose" : "Izvēlieties",
     "Copy to {target}" : "Kopēt uz {target}",
     "Copy" : "Kopēt",
@@ -198,11 +212,6 @@ OC.L10N.register(
     "Connect items to a project to make them easier to find" : "Savienojiet vienumus ar projektu, lai tos būtu vieglāk atrast",
     "New in" : "Jauns",
     "View changelog" : "Skatīt izmaiņu sarakstu",
-    "Very weak password" : "Ļoti vāja parole",
-    "Weak password" : "Vāja parole",
-    "So-so password" : "Viduvēja parole",
-    "Good password" : "Laba parole",
-    "Strong password" : "Spēcīga parole",
     "No action available" : "Nav pieejamu darbību",
     "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
     "Non-existing tag #{tag}" : "Neesoša birka #{tag}",
@@ -232,28 +241,12 @@ OC.L10N.register(
     "File: %s" : "Datne: %s",
     "Line: %s" : "Līnija: %s",
     "Trace" : "Izsekot",
-    "Security warning" : "Drošības brīdinājums",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Iespējams, ka datu mape un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
-    "Show password" : "Rādīt paroli",
-    "Toggle password visibility" : "Pārslēgt paroles redzamību",
-    "Storage & database" : "Krātuve & datubāze",
-    "Data folder" : "Datu mape",
-    "Configure the database" : "Konfigurēt datubāzi",
-    "Only %s is available." : "Tikai %s ir pieejams.",
-    "Install and activate additional PHP modules to choose other database types." : "Instalējiet un aktivizējiet papildus PHP moduļus lai izvēlētos citus datubāžu tipus.",
-    "For more details check out the documentation." : "Vairāk informācijas ir meklējama dokumentācijā.",
-    "Database account" : "Datubāzes konts",
-    "Database password" : "Datubāzes parole",
-    "Database name" : "Datubāzes nosaukums",
-    "Database tablespace" : "Datubāzes tabulas telpa",
-    "Database host" : "Datubāzes serveris",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lūdzu, norādiet porta numuru kopā ar resursdatora nosaukumu (piemēram, localhost: 5432).",
-    "Performance warning" : "Veiktspējas brīdinājums",
-    "Need help?" : "Vajadzīga palīdzība?",
-    "See the documentation" : "Skatiet dokumentāciju",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Šīs lietotnes pareizai darbībai ir nepieciešams JavaScript. Lūgums {linkstart}ieslēgt JavasScript{linkend} un pārlādēt lapu.",
     "App password" : "Lietotnes parole",
     "Grant access" : "Piešķirt pieeju",
+    "Account connected" : "Konts sasaistīts",
+    "Your client should now be connected!" : "Klientam tagad vajadzētu būt sasaistītam.",
+    "You can close this window." : "Šo logu var aizvērt.",
     "Previous" : "Iepriekšējā",
     "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
     "Email address" : "E-pasta adrese",
@@ -279,8 +272,19 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jāsazinās ar sistēmas pārvaldītāju, ja šis ziņojums nepazūd vai parādījās negaidīti",
     "Login with username or email" : "Pieteikties ar lietotājvārdu vai e-pasta adresi",
     "Login with username" : "Pieteikties ar lietotājvārdu",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tērzēšana, videozvani, ekrāna koplietošana, tiešsaistes sapulces un tīmekļa konferences - pārlūkprogrammā un ar mobilajām lietotnēm.",
+    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tērzēšana, videozvani, ekrāna kopīgošana, tiešsaistes sapulces un tīmekļa apspriešanās - pārlūkā un viedierīču lietotnēs.",
     "Edit Profile" : "Labot profilu",
-    "Error loading message template: {error}" : "Kļūda ielādējot ziņojuma veidni: {error}"
+    "Error loading message template: {error}" : "Kļūda ielādējot ziņojuma veidni: {error}",
+    "Very weak password" : "Ļoti vāja parole",
+    "Weak password" : "Vāja parole",
+    "So-so password" : "Viduvēja parole",
+    "Good password" : "Laba parole",
+    "Strong password" : "Spēcīga parole",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Iespējams, ka datu mape un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
+    "Show password" : "Rādīt paroli",
+    "Toggle password visibility" : "Pārslēgt paroles redzamību",
+    "Configure the database" : "Konfigurēt datubāzi",
+    "Only %s is available." : "Tikai %s ir pieejams.",
+    "Database account" : "Datubāzes konts"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
