@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Logg inn med en enhet",
     "Login or email" : "Pålogging eller e-post",
     "Your account is not setup for passwordless login." : "Kontoen din er ikke satt opp med passordløs innlogging.",
-    "Browser not supported" : "Nettleseren din støttes ikke!",
-    "Passwordless authentication is not supported in your browser." : "Passordløs innlogging støttes ikke av nettleseren din.",
     "Your connection is not secure" : "Tilkoblingen din er ikke sikker",
     "Passwordless authentication is only available over a secure connection." : "Passordløs innlogging støttes kun over en sikker tilkobling.",
+    "Browser not supported" : "Nettleseren din støttes ikke!",
+    "Passwordless authentication is not supported in your browser." : "Passordløs innlogging støttes ikke av nettleseren din.",
     "Reset password" : "Tilbakestill passord",
+    "Back to login" : "Tilbake til innlogging",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Hvis denne kontoen finnes, er det sendt en melding om tilbakestilling av passord til e-postadressen. Hvis du ikke mottar den, bekreft e-postadressen din og / eller logg inn, sjekk spam / søppelpostmappene dine eller spør din lokale administrasjon om hjelp.",
     "Couldn't send reset email. Please contact your administrator." : "Klarte ikke å sende e-post for tilbakestilling. Kontakt administratoren.",
     "Password cannot be changed. Please contact your administrator." : "Passordet kan ikke endres. Kontakt administratoren din.",
-    "Back to login" : "Tilbake til innlogging",
     "New password" : "Nytt passord",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dine filer er kryptert. Det finnes ingen måte å få dine data tilbake etter at passordet er nullstilt. Hvis du er usikker på hva du skal gjøre, vennligst kontakt din administrator før du fortsetter. Er du helt sikker på at du vil fortsette?",
     "I know what I'm doing" : "Jeg vet hva jeg gjør",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Innloggingskjemaet er deaktivert.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud-påloggingsskjemaet er deaktivert. Bruk et annet påloggingsalternativ hvis tilgjengelig, eller kontakt administrasjonen din.",
     "More actions" : "Flere handlinger",
+    "Security warning" : "Sikkerhetsadvarsel",
+    "Storage & database" : "Lagring og database",
+    "Data folder" : "Datamappe",
+    "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver flere PHP-moduler for å velge andre databasetyper.",
+    "For more details check out the documentation." : "Henvend deg til dokumentasjonen for flere detaljer.",
+    "Performance warning" : "Ytelsesadvarsel",
+    "You chose SQLite as database." : "Du velger å bruke SQLite som database.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite skal bare bli brukt for minimale- eller utvikler-installasjoner. I vanlig bruk anbefaler vi å bruke et annet bakstykke.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Hvis du bruker klienter for filsynkronisering så er bruk av SQLite absolutt ikke anbefalt.",
+    "Database user" : "Databasebruker",
+    "Database password" : "Databasepassord",
+    "Database name" : "Databasenavn",
+    "Database tablespace" : "Database-tabellområde",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Spesifiser portnr. sammen med servernavnet (f.eks., localhost:5432).",
+    "Database host" : "Databasevert",
+    "Installing …" : "Installerer ...",
+    "Install" : "Installer",
+    "Need help?" : "Trenger du hjelp?",
+    "See the documentation" : "Se dokumentasjonen",
     "{name} version {version} and above" : "{name} versjon {version} og nyere",
     "This browser is not supported" : "Denne nettleseren støttes ikke",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Nettleseren din støttes ikke. Vennligst oppgrader til en nyere versjon eller en støttet versjon.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skriv for å søke etter eksisterende prosjekter",
     "New in" : "Ny i",
     "View changelog" : "Se endringslogg",
-    "Very weak password" : "Veldig svakt passord",
-    "Weak password" : "Svakt passord",
-    "So-so password" : "Bob-bob-passord",
-    "Good password" : "Bra passord",
-    "Strong password" : "Sterkt passord",
     "No action available" : "Ingen handling tilgjengelig",
     "Error fetching contact actions" : "Feil ved innhenting av kontakt-handlinger",
     "Close \"{dialogTitle}\" dialog" : "Lukk \"{dialogTitle}\" dialogen",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Fil: %s",
     "Line: %s" : "Linje: %s",
     "Trace" : "Sporing",
-    "Security warning" : "Sikkerhetsadvarsel",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For informasjon om hvordan du skal konfigurere serveren skikkelig, les <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasjonen</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Opprett en administratorkonto</strong>",
-    "New admin account name" : "Navn på ny administratorkonto",
-    "New admin password" : "Passord for ny administratorkonto",
-    "Show password" : "Vis passord",
-    "Toggle password visibility" : "Vis passord av/på",
-    "Storage & database" : "Lagring og database",
-    "Data folder" : "Datamappe",
-    "Configure the database" : "Sett opp databasen",
-    "Only %s is available." : "Kun %s er tilgjengelig.",
-    "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver flere PHP-moduler for å velge andre databasetyper.",
-    "For more details check out the documentation." : "Henvend deg til dokumentasjonen for flere detaljer.",
-    "Database account" : "Databasekonto",
-    "Database password" : "Databasepassord",
-    "Database name" : "Databasenavn",
-    "Database tablespace" : "Database-tabellområde",
-    "Database host" : "Databasevert",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Spesifiser portnr. sammen med servernavnet (f.eks., localhost:5432).",
-    "Performance warning" : "Ytelsesadvarsel",
-    "You chose SQLite as database." : "Du velger å bruke SQLite som database.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite skal bare bli brukt for minimale- eller utvikler-installasjoner. I vanlig bruk anbefaler vi å bruke et annet bakstykke.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Hvis du bruker klienter for filsynkronisering så er bruk av SQLite absolutt ikke anbefalt.",
-    "Install" : "Installer",
-    "Installing …" : "Installerer ...",
-    "Need help?" : "Trenger du hjelp?",
-    "See the documentation" : "Se dokumentasjonen",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Det ser ut som at du forsøker å re installere Nextcloud. Filen CAN_INSTALL mangler imidlertid fra innstillingsmappen. Opprett filen CAN_INSTALL i innstillingsmappen for å fortsette.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kunne ikke fjerne CAN_INSTALL fra konfigurasjonsmappa. Vennligst fjern denne filen manuelt.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denne appen krever JavaScript for å fungere korrekt. {linkstart}Aktiver JavaScript{linkend} og last siden på nytt.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Endre profil",
     "The headline and about sections will show up here" : "Overskriften og om-seksjoner vil vises her",
     "Error loading message template: {error}" : "Feil ved lasting av meldingsmal: {error}",
+    "Very weak password" : "Veldig svakt passord",
+    "Weak password" : "Svakt passord",
+    "So-so password" : "Bob-bob-passord",
+    "Good password" : "Bra passord",
+    "Strong password" : "Sterkt passord",
     "Profile not found" : "Finner ikke profil",
-    "The profile does not exist." : "Profilen finnes ikke"
+    "The profile does not exist." : "Profilen finnes ikke",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For informasjon om hvordan du skal konfigurere serveren skikkelig, les <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasjonen</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Opprett en administratorkonto</strong>",
+    "New admin account name" : "Navn på ny administratorkonto",
+    "New admin password" : "Passord for ny administratorkonto",
+    "Show password" : "Vis passord",
+    "Toggle password visibility" : "Vis passord av/på",
+    "Configure the database" : "Sett opp databasen",
+    "Only %s is available." : "Kun %s er tilgjengelig.",
+    "Database account" : "Databasekonto"
 },
 "nplurals=2; plural=(n != 1);");
