@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Zaloguj się za pomocą urządzenia",
     "Login or email" : "Nazwa logowania lub e-mail",
     "Your account is not setup for passwordless login." : "Twoje konto nie jest skonfigurowane do logowania bez hasła.",
-    "Browser not supported" : "Przeglądarka nie jest obsługiwana",
-    "Passwordless authentication is not supported in your browser." : "Uwierzytelnianie bez hasła nie jest obsługiwane w przeglądarce.",
     "Your connection is not secure" : "Twoje połączenie nie jest bezpieczne",
     "Passwordless authentication is only available over a secure connection." : "Uwierzytelnianie bez hasła jest dostępne tylko przez bezpieczne połączenie.",
+    "Browser not supported" : "Przeglądarka nie jest obsługiwana",
+    "Passwordless authentication is not supported in your browser." : "Uwierzytelnianie bez hasła nie jest obsługiwane w przeglądarce.",
     "Reset password" : "Zresetuj hasło",
+    "Back to login" : "Powrót do logowania",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Jeśli to konto istnieje, wiadomość dotycząca resetowania hasła została wysłana na jego adres e-mail. Jeśli go nie otrzymasz, zweryfikuj swój adres e-mail i/lub nazwę logowania, sprawdź katalogi ze spamem/śmieciami lub poproś o pomoc lokalną administrację.",
     "Couldn't send reset email. Please contact your administrator." : "Nie mogę wysłać e-maila resetującego hasło. Skontaktuj się z administratorem.",
     "Password cannot be changed. Please contact your administrator." : "Hasło nie może zostać zmienione. Skontaktuj się z administratorem.",
-    "Back to login" : "Powrót do logowania",
     "New password" : "Nowe hasło",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Twoje pliki są szyfrowane. Po zresetowaniu hasła nie będzie możliwości odzyskania danych. Jeśli nie masz pewności, co zrobić, skontaktuj się z administratorem przed kontynuowaniem. Czy na pewno chcesz kontynuować?",
     "I know what I'm doing" : "Wiem co robię",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Formularz logowania jest wyłączony.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Formularz logowania Nextcloud jest wyłączony. Użyj innej opcji logowania, jeśli jest dostępna, lub skontaktuj się z administracją.",
     "More actions" : "Więcej akcji",
+    "Security warning" : "Ostrzeżenie bezpieczeństwa",
+    "Storage & database" : "Magazyn i baza danych",
+    "Data folder" : "Katalog danych",
+    "Install and activate additional PHP modules to choose other database types." : "Zainstaluj lub aktywuj dodatkowe moduły PHP, aby uzyskać możliwość wyboru innych typów baz danych.",
+    "For more details check out the documentation." : "Aby uzyskać więcej informacji zapoznaj się z dokumentacją.",
+    "Performance warning" : "Ostrzeżenie o wydajności",
+    "You chose SQLite as database." : "Wybrałeś SQLite jako bazę danych.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite powinien być używany tylko dla instancji minimalnych i rozwojowych. Dla rozwiniętej zalecamy inne zaplecze bazy danych.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jeśli używasz klientów do synchronizacji plików, używanie SQLite jest bardzo odradzane.",
+    "Database user" : "Użytkownik bazy danych",
+    "Database password" : "Hasło do bazy danych",
+    "Database name" : "Nazwa bazy danych",
+    "Database tablespace" : "Obszar tabel bazy danych",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Podaj numer portu wraz z nazwą hosta (np. localhost: 5432).",
+    "Database host" : "Host bazy danych",
+    "Installing …" : "Instalowanie…",
+    "Install" : "Zainstaluj",
+    "Need help?" : "Potrzebujesz pomocy?",
+    "See the documentation" : "Zapoznaj się z dokumentacją",
     "{name} version {version} and above" : "{name} wersja {version} i nowsze",
     "This browser is not supported" : "Ta przeglądarka nie jest obsługiwana",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Twoja przeglądarka nie jest wspierana. Uaktualnij do nowszej lub obsługiwanej wersji.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Wpisz rodzaj, aby wyszukać istniejące projekty",
     "New in" : "Nowość w",
     "View changelog" : "Przeglądaj listę zmian",
-    "Very weak password" : "Bardzo słabe hasło",
-    "Weak password" : "Słabe hasło",
-    "So-so password" : "Mało skomplikowane hasło",
-    "Good password" : "Dobre hasło",
-    "Strong password" : "Silne hasło",
     "No action available" : "Żadna akcja nie jest dostępna",
     "Error fetching contact actions" : "Błąd podczas pobierania akcji dla kontaktu",
     "Close \"{dialogTitle}\" dialog" : "Zamknij okno \"{dialogTitle}\"",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Plik: %s",
     "Line: %s" : "Linia: %s",
     "Trace" : "Ślad",
-    "Security warning" : "Ostrzeżenie bezpieczeństwa",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Twój katalog danych i pliki są prawdopodobnie dostępne z poziomu internetu, ponieważ plik .htaccess nie działa.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacje na temat prawidłowej konfiguracji serwera można znaleźć w <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentacji</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Utwórz konto administratora</strong>",
-    "New admin account name" : "Nowa nazwa konta administratora",
-    "New admin password" : "Nowe hasło administratora",
-    "Show password" : "Pokaż hasło",
-    "Toggle password visibility" : "Przełącz widoczność hasła",
-    "Storage & database" : "Magazyn i baza danych",
-    "Data folder" : "Katalog danych",
-    "Configure the database" : "Skonfiguruj bazę danych",
-    "Only %s is available." : "Dostępne jest tylko %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Zainstaluj lub aktywuj dodatkowe moduły PHP, aby uzyskać możliwość wyboru innych typów baz danych.",
-    "For more details check out the documentation." : "Aby uzyskać więcej informacji zapoznaj się z dokumentacją.",
-    "Database account" : "Konto bazy danych",
-    "Database password" : "Hasło do bazy danych",
-    "Database name" : "Nazwa bazy danych",
-    "Database tablespace" : "Obszar tabel bazy danych",
-    "Database host" : "Host bazy danych",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Podaj numer portu wraz z nazwą hosta (np. localhost: 5432).",
-    "Performance warning" : "Ostrzeżenie o wydajności",
-    "You chose SQLite as database." : "Wybrałeś SQLite jako bazę danych.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite powinien być używany tylko dla instancji minimalnych i rozwojowych. Dla rozwiniętej zalecamy inne zaplecze bazy danych.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Jeśli używasz klientów do synchronizacji plików, używanie SQLite jest bardzo odradzane.",
-    "Install" : "Zainstaluj",
-    "Installing …" : "Instalowanie…",
-    "Need help?" : "Potrzebujesz pomocy?",
-    "See the documentation" : "Zapoznaj się z dokumentacją",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Wygląda na to, że próbujesz ponownie zainstalować Nextcloud. Brakuje jednak pliku CAN_INSTALL w katalogu konfiguracyjnym. Aby kontynuować, utwórz plik CAN_INSTALL w katalogu konfiguracyjnym.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nie można usunąć CAN_INSTALL z katalogu konfiguracyjnego. Usuń ten plik ręcznie.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Aplikacja do poprawnego działania wymaga JavaScript. {linkstart}włącz JavaScript{linkend} i wczytaj stronę ponownie.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Edytuj profil",
     "The headline and about sections will show up here" : "Tutaj pojawi się nagłówek i informacje o sekcjach",
     "Error loading message template: {error}" : "Błąd podczas ładowania szablonu wiadomości: {error}",
+    "Very weak password" : "Bardzo słabe hasło",
+    "Weak password" : "Słabe hasło",
+    "So-so password" : "Mało skomplikowane hasło",
+    "Good password" : "Dobre hasło",
+    "Strong password" : "Silne hasło",
     "Profile not found" : "Nie znaleziono profilu",
-    "The profile does not exist." : "Profil nie istnieje."
+    "The profile does not exist." : "Profil nie istnieje.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Twój katalog danych i pliki są prawdopodobnie dostępne z poziomu internetu, ponieważ plik .htaccess nie działa.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacje na temat prawidłowej konfiguracji serwera można znaleźć w <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentacji</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Utwórz konto administratora</strong>",
+    "New admin account name" : "Nowa nazwa konta administratora",
+    "New admin password" : "Nowe hasło administratora",
+    "Show password" : "Pokaż hasło",
+    "Toggle password visibility" : "Przełącz widoczność hasła",
+    "Configure the database" : "Skonfiguruj bazę danych",
+    "Only %s is available." : "Dostępne jest tylko %s.",
+    "Database account" : "Konto bazy danych"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
