@@ -137,14 +137,14 @@ OC.L10N.register(
     "Password" : "Parolă",
     "Log in with a device" : "Logare cu dispozitiv",
     "Your account is not setup for passwordless login." : "Contul acesta nu este configurat pentru logare fără parolă.",
-    "Browser not supported" : "Browser incompatibil",
-    "Passwordless authentication is not supported in your browser." : "Autentificarea fără parolă nu este suportată de browser.",
     "Your connection is not secure" : "Conexiunea este nesigură",
     "Passwordless authentication is only available over a secure connection." : "Autentificarea fără parolă este disponibilă doar în cazul conexiunilor sigure.",
+    "Browser not supported" : "Browser incompatibil",
+    "Passwordless authentication is not supported in your browser." : "Autentificarea fără parolă nu este suportată de browser.",
     "Reset password" : "Resetează parola",
+    "Back to login" : "Înapoi la autentificare",
     "Couldn't send reset email. Please contact your administrator." : "Expedierea email-ului de resetare a eşuat. Vă rugăm să contactaţi administratorul dvs.",
     "Password cannot be changed. Please contact your administrator." : "Parola nu s-a putut schimba. Contactați administratorul.",
-    "Back to login" : "Înapoi la autentificare",
     "New password" : "Noua parolă",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Fișierele tale sunt criptate. Acestea nu vor mai putea fi recuperate după resetarea parolei. Dacă nu știți cumm să procedați, contactați administratorul înainte de a continua. Sigur doriți să continuați?",
     "I know what I'm doing" : "Știu ce fac",
@@ -187,6 +187,25 @@ OC.L10N.register(
     "Back" : "Înapoi",
     "Login form is disabled." : "Forma de login este dezactivată.",
     "More actions" : "Mai multe acțiuni",
+    "Security warning" : "Alertă de securitate",
+    "Storage & database" : "Stocare și baza de date",
+    "Data folder" : "Director date",
+    "Install and activate additional PHP modules to choose other database types." : "Instalează și activează module PHP adiționale pentru a putea alege alte tipuri de baze de date.",
+    "For more details check out the documentation." : "Pentru mai multe detalii verifică documentația.",
+    "Performance warning" : "Alertă de performanță",
+    "You chose SQLite as database." : "Ați ales SQLite ca bază de date.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ar trebui folosit doar pentru instanțe mici de dezvoltare. Pentru producție se recomandă utilizarea altei baze de date.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Dacă utilizați un client pentru sincronizarea fișierelor, utilizarea SQLite nu este recomandată.",
+    "Database user" : "Utilizatorul bazei de date",
+    "Database password" : "Parola bazei de date",
+    "Database name" : "Numele bazei de date",
+    "Database tablespace" : "Tabela de spațiu a bazei de date",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifică și numărul portului pe lângă hostname (ex: localhost;5432).",
+    "Database host" : "Bază date",
+    "Installing …" : "Se instalează ...",
+    "Install" : "Instalează",
+    "Need help?" : "Ai nevoie de ajutor?",
+    "See the documentation" : "Vezi documentația",
     "{name} version {version} and above" : "{name} versiunea {version} și superioară",
     "This browser is not supported" : "Browser incompatibil",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Browserul este incompatibil. Faceți upgrade la o versiune nouă.",
@@ -227,11 +246,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Tastați pentru căutarea proiectelor",
     "New in" : "Nou în",
     "View changelog" : "Vezi changelog",
-    "Very weak password" : "Parolă foarte slabă",
-    "Weak password" : "Parolă slabă",
-    "So-so password" : "Parolă medie",
-    "Good password" : "Parolă bună",
-    "Strong password" : "Parolă puternică",
     "No action available" : "Nici o acțiune disponibilă",
     "Error fetching contact actions" : "A apărut o eroare la preluarea activităților privind contactele",
     "Close \"{dialogTitle}\" dialog" : "Închide dialogul \"{dialogTitle}\"",
@@ -266,31 +280,6 @@ OC.L10N.register(
     "File: %s" : "Fișier: %s",
     "Line: %s" : "Linia: %s",
     "Trace" : "Traseu",
-    "Security warning" : "Alertă de securitate",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Directorul tău de date și fișiere sunt probabil accesibile de pe Internet, deoarece fișierul .htaccess nu funcționează.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pentru informații despre configurarea corectă a serverului, vedeți <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentația</a>.",
-    "Show password" : "Arată parola",
-    "Toggle password visibility" : "Vizibilitate parolă",
-    "Storage & database" : "Stocare și baza de date",
-    "Data folder" : "Director date",
-    "Configure the database" : "Configurează baza de date",
-    "Only %s is available." : "Doar %s este disponibil.",
-    "Install and activate additional PHP modules to choose other database types." : "Instalează și activează module PHP adiționale pentru a putea alege alte tipuri de baze de date.",
-    "For more details check out the documentation." : "Pentru mai multe detalii verifică documentația.",
-    "Database account" : "Cont bază de date",
-    "Database password" : "Parola bazei de date",
-    "Database name" : "Numele bazei de date",
-    "Database tablespace" : "Tabela de spațiu a bazei de date",
-    "Database host" : "Bază date",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Specifică și numărul portului pe lângă hostname (ex: localhost;5432).",
-    "Performance warning" : "Alertă de performanță",
-    "You chose SQLite as database." : "Ați ales SQLite ca bază de date.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ar trebui folosit doar pentru instanțe mici de dezvoltare. Pentru producție se recomandă utilizarea altei baze de date.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Dacă utilizați un client pentru sincronizarea fișierelor, utilizarea SQLite nu este recomandată.",
-    "Install" : "Instalează",
-    "Installing …" : "Se instalează ...",
-    "Need help?" : "Ai nevoie de ajutor?",
-    "See the documentation" : "Vezi documentația",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Se pare că doriți să reinstalați Nextcloud. Totuși, fișierul CAN_INSTALL lipsește din directorul configurației. Creați fișierul CAN_INSTALL în folderul configurației pentru a continua.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Nu se poate elimina VAN_INSTALL din folderul configurației. Eliminați-l manual.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Această aplicație necesită JavaScript pentru a funcționa corect. {linkstart}Activează JavaScript{linkend} și reîncarcă pagina.",
@@ -355,7 +344,19 @@ OC.L10N.register(
     "Edit Profile" : "Editare profil",
     "The headline and about sections will show up here" : "Secțiunile titlu și despre vor fi afișate aici",
     "Error loading message template: {error}" : "Eroare la încărcarea şablonului de mesaje: {error}",
+    "Very weak password" : "Parolă foarte slabă",
+    "Weak password" : "Parolă slabă",
+    "So-so password" : "Parolă medie",
+    "Good password" : "Parolă bună",
+    "Strong password" : "Parolă puternică",
     "Profile not found" : "Profil inexistent",
-    "The profile does not exist." : "Profilul nu există"
+    "The profile does not exist." : "Profilul nu există",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Directorul tău de date și fișiere sunt probabil accesibile de pe Internet, deoarece fișierul .htaccess nu funcționează.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pentru informații despre configurarea corectă a serverului, vedeți <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentația</a>.",
+    "Show password" : "Arată parola",
+    "Toggle password visibility" : "Vizibilitate parolă",
+    "Configure the database" : "Configurează baza de date",
+    "Only %s is available." : "Doar %s este disponibil.",
+    "Database account" : "Cont bază de date"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
