@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Войти с устройства",
     "Login or email" : "Имя пользователя или адрес эл. почты",
     "Your account is not setup for passwordless login." : "Ваша учётная запись не настроена на вход без пароля.",
-    "Browser not supported" : "Используемый браузер не поддерживается",
-    "Passwordless authentication is not supported in your browser." : "Ваш браузер не поддерживает безпарольную аутентификацию",
     "Your connection is not secure" : "Соединение установлено с использованием небезопасного протокола",
     "Passwordless authentication is only available over a secure connection." : "Вход без пароля возможет только через защищённое соединение",
+    "Browser not supported" : "Используемый браузер не поддерживается",
+    "Passwordless authentication is not supported in your browser." : "Ваш браузер не поддерживает безпарольную аутентификацию",
     "Reset password" : "Сбросить пароль",
+    "Back to login" : "Вернуться на страницу входа",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Если эта учётная запись существует, на ее адрес электронной почты было отправлено сообщение о сбросе пароля. Если вы его не получили, подтвердите свой адрес электронной почты и/или имя учетной записи, проверьте папки со спамом/нежелательной почтой или обратитесь за помощью к своему системному администратору.",
     "Couldn't send reset email. Please contact your administrator." : "Не удалось отправить письмо для сброса пароля. Свяжитесь со своим администратором.",
     "Password cannot be changed. Please contact your administrator." : "Пароль не может быть изменён. Свяжитесь со своим системным администратором.",
-    "Back to login" : "Вернуться на страницу входа",
     "New password" : "Новый пароль",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваши файлы хранятся в зашифрованном виде. После сброса пароля будет невозможно получить доступ к этим данным. Если вы не уверены, что делать дальше — обратитесь к своему системному администратору. Продолжить?",
     "I know what I'm doing" : "Я понимаю, что делаю",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "Форма входа отключена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Диалог входа отключен. Используйте другой способ входа или свяжитесь с администратором.",
     "More actions" : "Больше действий",
+    "Password is too weak" : "Пароль слишком слабый",
+    "Password is weak" : "Пароль слабый",
+    "Password is average" : "Пароль средний",
+    "Password is strong" : "Пароль надежный",
+    "Password is very strong" : "Пароль очень надежный",
+    "Password is extremely strong" : "Пароль очень надежный",
+    "Unknown password strength" : "Неизвестная надежность пароля",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш каталог данных и файлы, вероятно, доступны из Интернета, поскольку файл <code>.htaccess</code> не работает.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Информацию о том, как правильно настроить сервер,{linkStart} смотрите в документации.{linkEnd}",
+    "Autoconfig file detected" : "Обнаружен файл автоконфигурации",
+    "The setup form below is pre-filled with the values from the config file." : "Форма настройки ниже, предварительно заполнена значениями из файла конфигурации.",
+    "Security warning" : "Предупреждение безопасности",
+    "Create administration account" : "Создать учетную запись администратора",
+    "Administration account name" : "Имя учетной записи администратора",
+    "Administration account password" : "Пароль учетной записи администратора",
+    "Storage & database" : "Хранилище и база данных",
+    "Data folder" : "Каталог с данными",
+    "Database configuration" : "Конфигурация базы данных",
+    "Only {firstAndOnlyDatabase} is available." : "Только {firstAndOnlyDatabase} доступно.",
+    "Install and activate additional PHP modules to choose other database types." : "Установите и активируйте дополнительные модули PHP для возможности выбора других типов баз данных.",
+    "For more details check out the documentation." : "За дополнительными сведениями обратитесь к документации.",
+    "Performance warning" : "Предупреждение о производительности",
+    "You chose SQLite as database." : "Вы выбрали SQLite в качестве базы данных.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite следует использовать только для минимальных и разрабатываемых экземпляров. Для производства мы рекомендуем другую базу данных.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Настоятельно не рекомендуется использовать механизм баз данных SQLite при использовании синхронизации файлов с использованием приложений-клиентов.",
+    "Database user" : "Пользователь базы данных",
+    "Database password" : "Пароль базы данных",
+    "Database name" : "Имя базы данных",
+    "Database tablespace" : "Табличное пространство базы данных",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Пожалуйста укажите номер порта вместе с именем хоста (напр. localhost:5432)",
+    "Database host" : "Хост базы данных",
+    "localhost" : "локальный хост",
+    "Installing …" : "Установка ...",
+    "Install" : "Установить",
+    "Need help?" : "Требуется помощь?",
+    "See the documentation" : "Посмотреть документацию",
     "{name} version {version} and above" : "{name} версии {version} и новее",
     "This browser is not supported" : "Используемый браузер не поддерживается",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Используемый браузер не поддерживается. Обновитесь до более новой версии или используйте другой браузер.",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Нажмите, чтобы найти существующий проект",
     "New in" : "Новые возможности",
     "View changelog" : "Просмотреть изменения",
-    "Very weak password" : "Очень слабый пароль",
-    "Weak password" : "Слабый пароль",
-    "So-so password" : "Так себе пароль",
-    "Good password" : "Хороший пароль",
-    "Strong password" : "Надёжный пароль",
     "No action available" : "Нет доступных действий",
     "Error fetching contact actions" : "Ошибка получения действий контакта",
     "Close \"{dialogTitle}\" dialog" : "Закрыть «{dialogTitle}»",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "Файл: «%s»",
     "Line: %s" : "Строка: %s",
     "Trace" : "Трассировка",
-    "Security warning" : "Предупреждение безопасности",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются. Возможно, каталог данных и файлы свободно доступны из интернета.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Сведения о правильной настройке сервера можно найти в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документации</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Создайте учетную запись администратора</strong>",
-    "New admin account name" : "Новое имя учетной записи администратора",
-    "New admin password" : "Новый пароль администратора",
-    "Show password" : "Показать пароль",
-    "Toggle password visibility" : "Переключить видимость пароля",
-    "Storage & database" : "Хранилище и база данных",
-    "Data folder" : "Каталог с данными",
-    "Configure the database" : "Настройка базы данных",
-    "Only %s is available." : "Доступен только %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Установите и активируйте дополнительные модули PHP для возможности выбора других типов баз данных.",
-    "For more details check out the documentation." : "За дополнительными сведениями обратитесь к документации.",
-    "Database account" : "Учётная запись базы данных",
-    "Database password" : "Пароль базы данных",
-    "Database name" : "Имя базы данных",
-    "Database tablespace" : "Табличное пространство базы данных",
-    "Database host" : "Хост базы данных",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Пожалуйста укажите номер порта вместе с именем хоста (напр. localhost:5432)",
-    "Performance warning" : "Предупреждение о производительности",
-    "You chose SQLite as database." : "Вы выбрали SQLite в качестве базы данных.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite следует использовать только для минимальных и разрабатываемых экземпляров. Для производства мы рекомендуем другую базу данных.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Настоятельно не рекомендуется использовать механизм баз данных SQLite при использовании синхронизации файлов с использованием приложений-клиентов.",
-    "Install" : "Установить",
-    "Installing …" : "Установка ...",
-    "Need help?" : "Требуется помощь?",
-    "See the documentation" : "Посмотреть документацию",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Похоже, вы пытаетесь переустановить Nextcloud. Однако файл «CAN_INSTALL» отсутствует в вашем каталоге конфигурации. Чтобы продолжить создайте файл «CAN_INSTALL» в каталоге конфигурации.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не удалось удалить «CAN_INSTALL» из каталога конфигурации. Удалите этот файл вручную.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Для корректной работы приложения требуется JavaScript.  {linkstart}Включите JavaScript{linkend} и обновите страницу.",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "Редактирование профиля",
     "The headline and about sections will show up here" : "Разделы \"Заголовок\" и \"О вас\" будут отображаться здесь",
     "Error loading message template: {error}" : "Ошибка загрузки шаблона сообщений: {error}",
+    "Very weak password" : "Очень слабый пароль",
+    "Weak password" : "Слабый пароль",
+    "So-so password" : "Так себе пароль",
+    "Good password" : "Хороший пароль",
+    "Strong password" : "Надёжный пароль",
     "Profile not found" : "Профиль не найден",
-    "The profile does not exist." : "Профиль не существует"
+    "The profile does not exist." : "Профиль не существует",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Правила файла .htaccess не выполняются. Возможно, каталог данных и файлы свободно доступны из интернета.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Сведения о правильной настройке сервера можно найти в <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документации</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Создайте учетную запись администратора</strong>",
+    "New admin account name" : "Новое имя учетной записи администратора",
+    "New admin password" : "Новый пароль администратора",
+    "Show password" : "Показать пароль",
+    "Toggle password visibility" : "Переключить видимость пароля",
+    "Configure the database" : "Настройка базы данных",
+    "Only %s is available." : "Доступен только %s.",
+    "Database account" : "Учётная запись базы данных"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
