@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Пријава са уређајем",
     "Login or email" : "Име за пријаву или и-мејл",
     "Your account is not setup for passwordless login." : "Ваш налог није подешен за пријаву без лозинке.",
-    "Browser not supported" : "Веб читач није подржан",
-    "Passwordless authentication is not supported in your browser." : "Ваш веб читач не подржава пријављивање без лозинке.",
     "Your connection is not secure" : "Ваша веза није безбедна",
     "Passwordless authentication is only available over a secure connection." : "Пријављивање без лозинке је доступно само на безбедним конекцијама.",
+    "Browser not supported" : "Веб читач није подржан",
+    "Passwordless authentication is not supported in your browser." : "Ваш веб читач не подржава пријављивање без лозинке.",
     "Reset password" : "Ресетуј лозинку",
+    "Back to login" : "Назад на пријаву",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ако овај налог постоји, на његову и-мејл адресу је послата порука за ресетовање лозинке. Ако је не примите, потврдите своју и-мејл адресу и/или име за пријаву, проверите фолдере за нежељену пошту, или потражите помоћ свог локалног администратора.",
     "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем поруку за ресетовање. Контактирајте администратора.",
     "Password cannot be changed. Please contact your administrator." : "Лозинка не може да се промени. Молимо вас контактирајте администратора.",
-    "Back to login" : "Назад на пријаву",
     "New password" : "Нова лозинка",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваши фајлови су шифровани. Не постоји ниједан начин да се Ваши подаци поврате ако се лозинка сад ресетује. Уколико нисте сигурни шта да радите, контактирајте Вашег администратора пре него што наставите. Да ли стварно желите да наставите?",
     "I know what I'm doing" : "Знам шта радим",
@@ -207,6 +207,42 @@ OC.L10N.register(
     "Login form is disabled." : "Форма за пријаву је искључена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud формулар за пријаву је искључен. Ако је доступна, користите неку другу могућност пријаве, или се обратите администрацији.",
     "More actions" : "Још акција",
+    "Password is too weak" : "Лозинка је сувише слаба",
+    "Password is weak" : "Лозинка је слаба",
+    "Password is average" : "Лозинка је просечна",
+    "Password is strong" : "Лозинка је јака",
+    "Password is very strong" : "Лозинка је веома јака",
+    "Password is extremely strong" : "Лозинка је екстремно јака",
+    "Unknown password strength" : "Лозинка је непознате јачине",
+    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер <code>.htaccess</code> фајл не ради.",
+    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "За информације у вези са правилним подешавањем вашег сервера, молимо вас да {linkStart}погледајте документацију{linkEnd}",
+    "Autoconfig file detected" : "Откривен је фајл аутоматског подешавања",
+    "The setup form below is pre-filled with the values from the config file." : "Формулар подешавања испод је унапред попуњен са вредностима из конфигурационог фајла.",
+    "Security warning" : "Безбедносно упозорење",
+    "Create administration account" : "Направи административни налог",
+    "Administration account name" : "Име административног налога",
+    "Administration account password" : "Лозинка административног налога",
+    "Storage & database" : "Складиште и база података",
+    "Data folder" : "Фасцикла за податке",
+    "Database configuration" : "Конфигурација базе података",
+    "Only {firstAndOnlyDatabase} is available." : "Доступна је само {firstAndOnlyDatabase}.",
+    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне „ПХП“ модуле за одабир других база података.",
+    "For more details check out the documentation." : "За више детаља погледајте документацију.",
+    "Performance warning" : "Упозорење о перформансама",
+    "You chose SQLite as database." : "Одабрали сте SQLite за базу података.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за најмање инстанце или за инстанце за развој. За продукцију, препоручујемо други тип база података.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Коришћење SQLite базе података нарочите није препоручљиво ако користите клијенте за синхронизацију фајлова.",
+    "Database user" : "Корисник базе",
+    "Database password" : "Лозинка базе",
+    "Database name" : "Назив базе",
+    "Database tablespace" : "Радни простор базе података",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Наведите и број порта у имену домаћина (нпр. localhost:5432).",
+    "Database host" : "Домаћин базе",
+    "localhost" : "локални хост",
+    "Installing …" : "Инсталирам ...",
+    "Install" : "Инсталирај",
+    "Need help?" : "Треба вам помоћ?",
+    "See the documentation" : "Погледајте документацију",
     "{name} version {version} and above" : "{name} верзија {version} и новије",
     "This browser is not supported" : "Овај веб читач није подржан",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш веб читач није подржан. Молимо вас да га ажурирате на новију верзију, или да инсталирате подржани читач.",
@@ -247,11 +283,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Крените да куцате да тражите постојеће пројекте",
     "New in" : "Ново у",
     "View changelog" : "Погледајте дневник измена",
-    "Very weak password" : "Веома слаба лозинка",
-    "Weak password" : "Слаба лозинка",
-    "So-so password" : "Осредња лозинка",
-    "Good password" : "Добра лозинка",
-    "Strong password" : "Јака лозинка",
     "No action available" : "Нема доступне радње",
     "Error fetching contact actions" : "Грешка приликом дохватања акција над контактима",
     "Close \"{dialogTitle}\" dialog" : "Затвори дијалог „{dialogTitle}”",
@@ -289,34 +320,6 @@ OC.L10N.register(
     "File: %s" : "Фајл: %s",
     "Line: %s" : "Линија: %s",
     "Trace" : "Траг",
-    "Security warning" : "Безбедносно упозорење",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацију</a>.",
-    "<strong>Create an admin account</strong>" : " <strong>Направи административни налог</strong>",
-    "New admin account name" : "Име новог административног налога",
-    "New admin password" : "Лозинка новог административног налога",
-    "Show password" : "Прикажи лозинку",
-    "Toggle password visibility" : "Укључи/искључи видљивост лозинке",
-    "Storage & database" : "Складиште и база података",
-    "Data folder" : "Фасцикла за податке",
-    "Configure the database" : "Подешавање базе",
-    "Only %s is available." : "Само %s је доступна.",
-    "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне „ПХП“ модуле за одабир других база података.",
-    "For more details check out the documentation." : "За више детаља погледајте документацију.",
-    "Database account" : "Налог базе података",
-    "Database password" : "Лозинка базе",
-    "Database name" : "Назив базе",
-    "Database tablespace" : "Радни простор базе података",
-    "Database host" : "Домаћин базе",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Наведите и број порта у имену домаћина (нпр. localhost:5432).",
-    "Performance warning" : "Упозорење о перформансама",
-    "You chose SQLite as database." : "Одабрали сте SQLite за базу података.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite треба да се користи само за најмање инстанце или за инстанце за развој. За продукцију, препоручујемо други тип база података.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Коришћење SQLite базе података нарочите није препоручљиво ако користите клијенте за синхронизацију фајлова.",
-    "Install" : "Инсталирај",
-    "Installing …" : "Инсталирам ...",
-    "Need help?" : "Треба вам помоћ?",
-    "See the documentation" : "Погледајте документацију",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Делује као да покушавате да реинсталирате Nextcloud. Међутим, фајл CAN_INSTALL фали из конфигурационог директоријума, Молимо креирајте фајл CAN_INSTALL у овом директоријуму да бисте наставили.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Не могу да уклоним CAN_INSTALL из конфигурационе фасцикле. Уклоните овај фајл ручно.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ова апликација захтева Јава скрипт за исправан рад. {linkstart}Омогућите Јава скрипт{linkend} и поново учитајте страницу.",
@@ -385,7 +388,22 @@ OC.L10N.register(
     "Edit Profile" : "Уреди профил",
     "The headline and about sections will show up here" : "Овде ће се појавити насловна линија и одељак „о”",
     "Error loading message template: {error}" : "Грешка при учитавању шаблона поруке: {error}",
+    "Very weak password" : "Веома слаба лозинка",
+    "Weak password" : "Слаба лозинка",
+    "So-so password" : "Осредња лозинка",
+    "Good password" : "Добра лозинка",
+    "Strong password" : "Јака лозинка",
     "Profile not found" : "Није пронађен профил",
-    "The profile does not exist." : "Профил не постоји."
+    "The profile does not exist." : "Профил не постоји.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацију</a>.",
+    "<strong>Create an admin account</strong>" : " <strong>Направи административни налог</strong>",
+    "New admin account name" : "Име новог административног налога",
+    "New admin password" : "Лозинка новог административног налога",
+    "Show password" : "Прикажи лозинку",
+    "Toggle password visibility" : "Укључи/искључи видљивост лозинке",
+    "Configure the database" : "Подешавање базе",
+    "Only %s is available." : "Само %s је доступна.",
+    "Database account" : "Налог базе података"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
