@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Logga in med en enhet",
     "Login or email" : "Användarnamn eller e-post",
     "Your account is not setup for passwordless login." : "Ditt konto är inte inställt för inloggning utan lösenord.",
-    "Browser not supported" : "Webbläsaren stöds inte",
-    "Passwordless authentication is not supported in your browser." : "Lösenordsfri autentisering stöds inte i din webbläsare.",
     "Your connection is not secure" : "Din anslutning är inte säker",
     "Passwordless authentication is only available over a secure connection." : "Lösenordsfri autentisering är endast tillgänglig via en säker anslutning.",
+    "Browser not supported" : "Webbläsaren stöds inte",
+    "Passwordless authentication is not supported in your browser." : "Lösenordsfri autentisering stöds inte i din webbläsare.",
     "Reset password" : "Återställ lösenord",
+    "Back to login" : "Tillbaka till inloggning",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Om det här kontot finns har ett meddelande om lösenordsåterställning skickats till dess e-postadress. Om du inte får det, verifiera din e-postadress och/eller kontonamn, kontrollera dina skräppost-/skräpmappar eller be din lokala administration om hjälp.",
     "Couldn't send reset email. Please contact your administrator." : "Kunde inte skicka återställningsmejl. Kontakta din administratör.",
     "Password cannot be changed. Please contact your administrator." : "Lösenordet kan inte ändras. Vänligen kontakta din administratör.",
-    "Back to login" : "Tillbaka till inloggning",
     "New password" : "Nytt lösenord",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dina filer är krypterade. Det kommer inte att finnas något sätt att få tillbaka din data efter att ditt lösenord har återställs. Om du är osäker på hur du ska göra, kontakta din administratör innan du fortsätter. Är du verkligen säker på att du vill fortsätta?",
     "I know what I'm doing" : "Jag vet vad jag gör",
@@ -207,6 +207,32 @@ OC.L10N.register(
     "Login form is disabled." : "Inloggningsfomuläret är inaktiverat.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Inloggningsformuläret är inaktiverat. Använd om tillgänglig en annan inloggnings-metod eller kontakta administrationen.",
     "More actions" : "Fler händelser",
+    "Password is too weak" : "Lösenordet är för svagt",
+    "Password is weak" : "Lösenordet är svagt",
+    "Password is average" : "Lösenordet är medelstarkt",
+    "Password is strong" : "Lösenordet är starkt",
+    "Password is very strong" : "Lösenordet är mycket starkt",
+    "Password is extremely strong" : "Lösenordet är extremt starkt",
+    "Unknown password strength" : "Okänd lösenordsstyrka",
+    "Security warning" : "Säkerhetsvarning",
+    "Storage & database" : "Lagring & databas",
+    "Data folder" : "Datamapp",
+    "Install and activate additional PHP modules to choose other database types." : "Installera och aktivera ytterligare moduler för att kunna välja andra databas-typer.",
+    "For more details check out the documentation." : "För mer detaljer se dokumentationen",
+    "Performance warning" : "Prestandavarning",
+    "You chose SQLite as database." : "Du valde SQLite som databas.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bör endast användas till små installationer och installationer avsedda för utveckling. För produktion rekommenderar vi byte till annan databas.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Om du använder synkklienter avråder vi starkt från användning av SQLite.",
+    "Database user" : "Databasanvändare",
+    "Database password" : "Lösenord till databasen",
+    "Database name" : "Databasnamn",
+    "Database tablespace" : "Databas tabellutrymme",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vänligen ange portnumret tillsammans med värdnamnet (t.ex. localhost:5432).",
+    "Database host" : "Databasserver",
+    "Installing …" : "Installerar …",
+    "Install" : "Installera",
+    "Need help?" : "Behövs hjälp?",
+    "See the documentation" : "Se dokumentationen",
     "{name} version {version} and above" : "{name} version {version} och högre",
     "This browser is not supported" : "Den här webbläsaren stöds inte",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Din webbläsare stöds inte. Uppgradera till en nyare version eller en som stöds.",
@@ -247,11 +273,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Skriv för att söka efter befintliga projekt",
     "New in" : "Ny i",
     "View changelog" : "Visa ändringslogg",
-    "Very weak password" : "Väldigt svagt lösenord",
-    "Weak password" : "Svagt lösenord",
-    "So-so password" : "Okej lösenord",
-    "Good password" : "Bra lösenord",
-    "Strong password" : "Starkt lösenord",
     "No action available" : "Ingen åtgärd tillgänglig",
     "Error fetching contact actions" : "Fel vid hämtning av kontakthändelser",
     "Close \"{dialogTitle}\" dialog" : "Stäng \"{dialogTitle}\"",
@@ -289,34 +310,6 @@ OC.L10N.register(
     "File: %s" : "Fil: %s",
     "Line: %s" : "Rad: %s",
     "Trace" : "Spåra",
-    "Security warning" : "Säkerhetsvarning",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Din datakatalog och filer är förmodligen tillgängliga från Internet eftersom filen .htaccess inte fungerar.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Information hur din server bäst konfigureras kan hittas i <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Skapa ett administratörskonto</strong>",
-    "New admin account name" : "Namn på administratörskonto",
-    "New admin password" : "Lösenord för administratörskonto",
-    "Show password" : "Visa lösenord",
-    "Toggle password visibility" : "Växla lösenordsynlighet",
-    "Storage & database" : "Lagring & databas",
-    "Data folder" : "Datamapp",
-    "Configure the database" : "Konfigurera databasen",
-    "Only %s is available." : "Endast %s är tillgänglig.",
-    "Install and activate additional PHP modules to choose other database types." : "Installera och aktivera ytterligare moduler för att kunna välja andra databas-typer.",
-    "For more details check out the documentation." : "För mer detaljer se dokumentationen",
-    "Database account" : "Databaskonto",
-    "Database password" : "Lösenord till databasen",
-    "Database name" : "Databasnamn",
-    "Database tablespace" : "Databas tabellutrymme",
-    "Database host" : "Databasserver",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vänligen ange portnumret tillsammans med värdnamnet (t.ex. localhost:5432).",
-    "Performance warning" : "Prestandavarning",
-    "You chose SQLite as database." : "Du valde SQLite som databas.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite bör endast användas till små installationer och installationer avsedda för utveckling. För produktion rekommenderar vi byte till annan databas.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Om du använder synkklienter avråder vi starkt från användning av SQLite.",
-    "Install" : "Installera",
-    "Installing …" : "Installerar …",
-    "Need help?" : "Behövs hjälp?",
-    "See the documentation" : "Se dokumentationen",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Det ser ut som att du försöker installera om Nextcloud. Men filen CAN_INSTALL saknas i din konfigurationskatalog. Skapa filen CAN_INSTALL i din konfigurationsmapp för att fortsätta.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Det gick inte att ta bort CAN_INSTALL från konfigurationsmappen. Ta bort den här filen manuellt.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Denna applikationen kräver JavaScript för att fungera korrekt. {linkstart}aktivera JavaScript{linkend} och uppdatera sidan.",
@@ -385,7 +378,22 @@ OC.L10N.register(
     "Edit Profile" : "Redigera profil",
     "The headline and about sections will show up here" : "Rubriken och avsnitten \"om\" kommer att dyka upp här",
     "Error loading message template: {error}" : "Fel uppstod under inläsningen av meddelandemallen: {error}",
+    "Very weak password" : "Väldigt svagt lösenord",
+    "Weak password" : "Svagt lösenord",
+    "So-so password" : "Okej lösenord",
+    "Good password" : "Bra lösenord",
+    "Strong password" : "Starkt lösenord",
     "Profile not found" : "Profil kunde inte hittas",
-    "The profile does not exist." : "Profilen existerar inte."
+    "The profile does not exist." : "Profilen existerar inte.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Din datakatalog och filer är förmodligen tillgängliga från Internet eftersom filen .htaccess inte fungerar.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Information hur din server bäst konfigureras kan hittas i <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentationen</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Skapa ett administratörskonto</strong>",
+    "New admin account name" : "Namn på administratörskonto",
+    "New admin password" : "Lösenord för administratörskonto",
+    "Show password" : "Visa lösenord",
+    "Toggle password visibility" : "Växla lösenordsynlighet",
+    "Configure the database" : "Konfigurera databasen",
+    "Only %s is available." : "Endast %s är tillgänglig.",
+    "Database account" : "Databaskonto"
 },
 "nplurals=2; plural=(n != 1);");
