@@ -134,14 +134,14 @@ OC.L10N.register(
     "Log in with a device" : "เข้าสู่ระบบด้วยอุปกรณ์",
     "Login or email" : "ล็อกอินหรืออีเมล",
     "Your account is not setup for passwordless login." : "บัญชีของคุณยังไม่ได้ตั้งค่าการเข้าสู่ระบบแบบไร้รหัสผ่าน",
-    "Browser not supported" : "ไม่รองรับเบราว์เซอร์",
-    "Passwordless authentication is not supported in your browser." : "เบราว์เซอร์ของคุณไม่รองรับการรับรองความถูกต้องแบบไร้รหัสผ่าน",
     "Your connection is not secure" : "การเชื่อมต่อของคุณไม่ปลอดภัย",
     "Passwordless authentication is only available over a secure connection." : "สามารถใช้การรับรองความถูกต้องแบบไร้รหัสผ่านผ่านการเชื่อมต่อที่ปลอดภัยเท่านั้น",
+    "Browser not supported" : "ไม่รองรับเบราว์เซอร์",
+    "Passwordless authentication is not supported in your browser." : "เบราว์เซอร์ของคุณไม่รองรับการรับรองความถูกต้องแบบไร้รหัสผ่าน",
     "Reset password" : "ตั้งรหัสผ่านใหม่",
+    "Back to login" : "กลับสู่หน้าเข้าสู่ระบบ",
     "Couldn't send reset email. Please contact your administrator." : "ไม่สามารถส่งข้อมูลการตั้งค่าไปยังอีเมลของคุณ กรุณาติดต่อผู้ดูแลระบบ",
     "Password cannot be changed. Please contact your administrator." : "ไม่สามารถเปลี่ยนรหัสผ่าน กรุณาติดต่อผู้ดูแลระบบ",
-    "Back to login" : "กลับสู่หน้าเข้าสู่ระบบ",
     "New password" : "รหัสผ่านใหม่",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "ไฟล์ของคุณถูกเข้ารหัส คุณจะไม่สามารถรับข้อมูลของคุณกลับมาหลังจากที่ตั้งรหัสผ่านใหม่แล้ว หากคุณไม่แน่ใจว่าควรทำอย่างไร โปรดติดต่อผู้ดูแลระบบของคุณก่อนดำเนินการต่อ ต้องการดำเนินการต่อหรือไม่?",
     "I know what I'm doing" : "ฉันรู้ว่าฉันกำลังทำอะไรอยู่",
@@ -179,6 +179,25 @@ OC.L10N.register(
     "Back to login form" : "กลับสู่แบบฟอร์มเข้าสู่ระบบ",
     "Back" : "ย้อนกลับ",
     "Login form is disabled." : "ฟอร์มล็อกอินถูกปิดใช้งาน",
+    "Security warning" : "คำเตือนความปลอดภัย",
+    "Storage & database" : "พื้นที่จัดเก็บข้อมูลและฐานข้อมูล",
+    "Data folder" : "โฟลเดอร์เก็บข้อมูล",
+    "Install and activate additional PHP modules to choose other database types." : "ติดตั้งและเปิดใช้งานโมดูล PHP เพิ่มเติมเพื่อเลือกชนิดฐานข้อมูลอื่น ๆ",
+    "For more details check out the documentation." : "สำหรับรายละเอียดเพิ่มเติมสามารถตรวจสอบได้ที่<a href=\"%s\" target=\"_blank\">เอกสารประกอบ</a>",
+    "Performance warning" : "คำเตือนเรื่องประสิทธิภาพ",
+    "You chose SQLite as database." : "คุณเลือก SQLite เป็นฐานข้อมูล",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "ควรใช้ SQLite เฉพาะการทำงานขนาดเล็กและการพัฒนาเท่านั้น สำหรับการใช้งานจริง เราแนะนำให้ใช้แบ็กเอนด์ฐานข้อมูลแบบอื่น",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "หากคุณใช้ไคลเอ็นต์เพื่อซิงค์ไฟล์ ไม่แนะนำให้ใช้ SQLite อย่างยิ่ง",
+    "Database user" : "ชื่อผู้ใช้ฐานข้อมูล",
+    "Database password" : "รหัสผ่านฐานข้อมูล",
+    "Database name" : "ชื่อฐานข้อมูล",
+    "Database tablespace" : "พื้นที่ตารางในฐานข้อมูล",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "โปรดระบุหมายเลขพอร์ตพร้อมชื่อโฮสต์ (เช่น localhost:5432)",
+    "Database host" : "โฮสต์ฐานข้อมูล",
+    "Installing …" : "กำลังติดตั้ง …",
+    "Install" : "ติดตั้ง",
+    "Need help?" : "ต้องการความช่วยเหลือ?",
+    "See the documentation" : "ดูเอกสารประกอบ",
     "{name} version {version} and above" : "{name} รุ่น {version} ขึ้นไป",
     "This browser is not supported" : "เบราว์เซอร์นี้ไม่ได้รับการสนับสนุน",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "เบราว์เซอร์ของคุณไม่ได้รับการสนับสนุน กรุณาอัปเกรดเป็นรุ่นที่ใหม่กว่าหรือเบราว์เซอร์ที่สนับสนุน",
@@ -219,11 +238,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "พิมพ์เพื่อค้นหาโครงการที่มีอยู่",
     "New in" : "ใหม่ใน",
     "View changelog" : "ดูบันทึกการเปลี่ยนแปลง",
-    "Very weak password" : "รหัสผ่านระดับต่ำมาก",
-    "Weak password" : "รหัสผ่านระดับต่ำ",
-    "So-so password" : "รหัสผ่านระดับปกติ",
-    "Good password" : "รหัสผ่านระดับดี",
-    "Strong password" : "รหัสผ่านระดับดีมาก",
     "No action available" : "ไม่มีการกระทำที่ใช้ได้",
     "Error fetching contact actions" : "เกิดข้อผิดพลาดในการดึงการกระทำรายชื่อ",
     "Close \"{dialogTitle}\" dialog" : "ปิดกล่องโต้ตอบ \"{dialogTitle}\"",
@@ -258,31 +272,6 @@ OC.L10N.register(
     "File: %s" : "ไฟล์: %s",
     "Line: %s" : "บรรทัด: %s",
     "Trace" : "ร่องรอย",
-    "Security warning" : "คำเตือนความปลอดภัย",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ไดเรกทอรี data และไฟล์ของคุณอาจเข้าถึงได้จากอินเทอร์เน็ต เพราะไฟล์ .htaccess ไม่ทำงาน",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "สำหรับวิธีการกำหนดค่าเซิร์ฟเวอร์ของคุณอย่างถูกต้อง โปรดดู<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">เอกสารประกอบ</a>",
-    "Show password" : "แสดงรหัสผ่าน",
-    "Toggle password visibility" : "เปิด-ปิด การมองเห็นรหัสผ่าน",
-    "Storage & database" : "พื้นที่จัดเก็บข้อมูลและฐานข้อมูล",
-    "Data folder" : "โฟลเดอร์เก็บข้อมูล",
-    "Configure the database" : "ตั้งค่าฐานข้อมูล",
-    "Only %s is available." : "เฉพาะ %s สามารถใช้ได้",
-    "Install and activate additional PHP modules to choose other database types." : "ติดตั้งและเปิดใช้งานโมดูล PHP เพิ่มเติมเพื่อเลือกชนิดฐานข้อมูลอื่น ๆ",
-    "For more details check out the documentation." : "สำหรับรายละเอียดเพิ่มเติมสามารถตรวจสอบได้ที่<a href=\"%s\" target=\"_blank\">เอกสารประกอบ</a>",
-    "Database account" : "บัญชีฐานข้อมูล",
-    "Database password" : "รหัสผ่านฐานข้อมูล",
-    "Database name" : "ชื่อฐานข้อมูล",
-    "Database tablespace" : "พื้นที่ตารางในฐานข้อมูล",
-    "Database host" : "โฮสต์ฐานข้อมูล",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "โปรดระบุหมายเลขพอร์ตพร้อมชื่อโฮสต์ (เช่น localhost:5432)",
-    "Performance warning" : "คำเตือนเรื่องประสิทธิภาพ",
-    "You chose SQLite as database." : "คุณเลือก SQLite เป็นฐานข้อมูล",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "ควรใช้ SQLite เฉพาะการทำงานขนาดเล็กและการพัฒนาเท่านั้น สำหรับการใช้งานจริง เราแนะนำให้ใช้แบ็กเอนด์ฐานข้อมูลแบบอื่น",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "หากคุณใช้ไคลเอ็นต์เพื่อซิงค์ไฟล์ ไม่แนะนำให้ใช้ SQLite อย่างยิ่ง",
-    "Install" : "ติดตั้ง",
-    "Installing …" : "กำลังติดตั้ง …",
-    "Need help?" : "ต้องการความช่วยเหลือ?",
-    "See the documentation" : "ดูเอกสารประกอบ",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "ดูเหมือนว่าคุณกำลังพยายามติดตั้ง Nextcloud ใหม่ แต่ในไดเรกทอรี config ของคุณไม่มีไฟล์ CAN_INSTALL โปรดสร้างไฟล์ CAN_INSTALL ในโฟลเดอร์ config ของคุณก่อนดำเนินการต่อ",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "ไม่สามารถลบไฟล์ CAN_INSTALL จากโฟลเดอร์ config โปรดลบไฟล์นี้ออกด้วยตัวเอง",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "โปรแกรมนี้ต้องการ JavaScript สำหรับการทำงานที่ถูกต้อง กรุณา{linkstart}เปิดใช้งาน JavaScript{linkend} และโหลดหน้าเว็บใหม่",
@@ -345,7 +334,19 @@ OC.L10N.register(
     "{user} has not added any info yet" : "{user} ยังไม่ได้เพิ่มข้อมูลใด ๆ",
     "Edit Profile" : "แก้ไขโปรไฟล์",
     "Error loading message template: {error}" : "เกิดข้อผิดพลาดขณะกำลังโหลดเทมเพลตข้อความ: {error} ",
+    "Very weak password" : "รหัสผ่านระดับต่ำมาก",
+    "Weak password" : "รหัสผ่านระดับต่ำ",
+    "So-so password" : "รหัสผ่านระดับปกติ",
+    "Good password" : "รหัสผ่านระดับดี",
+    "Strong password" : "รหัสผ่านระดับดีมาก",
     "Profile not found" : "ไม่พบโปรไฟล์",
-    "The profile does not exist." : "โปรไฟล์นี้ไม่มีอยู่"
+    "The profile does not exist." : "โปรไฟล์นี้ไม่มีอยู่",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ไดเรกทอรี data และไฟล์ของคุณอาจเข้าถึงได้จากอินเทอร์เน็ต เพราะไฟล์ .htaccess ไม่ทำงาน",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "สำหรับวิธีการกำหนดค่าเซิร์ฟเวอร์ของคุณอย่างถูกต้อง โปรดดู<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">เอกสารประกอบ</a>",
+    "Show password" : "แสดงรหัสผ่าน",
+    "Toggle password visibility" : "เปิด-ปิด การมองเห็นรหัสผ่าน",
+    "Configure the database" : "ตั้งค่าฐานข้อมูล",
+    "Only %s is available." : "เฉพาะ %s สามารถใช้ได้",
+    "Database account" : "บัญชีฐานข้อมูล"
 },
 "nplurals=1; plural=0;");
