@@ -154,15 +154,15 @@ OC.L10N.register(
     "Log in with a device" : "Увійти за допомогою пристрою",
     "Login or email" : "Ім'я облікового запису або адреса ел.пошти",
     "Your account is not setup for passwordless login." : "Ваш обліковий запис не налаштовано на безпарольний вхід.",
-    "Browser not supported" : "Оглядач не підтримується",
-    "Passwordless authentication is not supported in your browser." : "Ваш браузер не підтримує безпарольний вхід.",
     "Your connection is not secure" : "Ваше зʼєднання не захищене",
     "Passwordless authentication is only available over a secure connection." : "Авторизація без пароля можлива лише при безпечному з'єднанні.",
+    "Browser not supported" : "Оглядач не підтримується",
+    "Passwordless authentication is not supported in your browser." : "Ваш браузер не підтримує безпарольний вхід.",
     "Reset password" : "Відновити пароль",
+    "Back to login" : "Повернутися на сторінку входу",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "На вашу ел.адресу було надіслано повідомлення про зміну пароля. Якщо ви його не отримали, перевірте адресу ел.пошти, ім'я користувача, скриньку зі спамом або зверніться до адміністратора.",
     "Couldn't send reset email. Please contact your administrator." : "Не вдалося надіслати повідомлення для відновлення пароля. Прохання сконтактувати з адміністратором.",
     "Password cannot be changed. Please contact your administrator." : "Пароль не можна змінити. Будь ласка, зверніться до свого адміністратора.",
-    "Back to login" : "Повернутися на сторінку входу",
     "New password" : "Новий пароль",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Ваші файли зашифровано. У разі перевстановлення паролю ви не зможете отримати доступ до них. Якщо ви не впевнені, що робити, будь ласка, сконтактуйте з адміністратором перед продовженням. Дійсно продовжити?",
     "I know what I'm doing" : "Я знаю що роблю",
@@ -207,6 +207,25 @@ OC.L10N.register(
     "Login form is disabled." : "Форма входу вимкнена.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Форму авторизації у хмарі Nextcloud вимкнено. Скористайтеся іншим способом входу, якщо є така можливість, або сконтактуйте з адміністратором.",
     "More actions" : "Більше дій",
+    "Security warning" : "Попередження безпеки",
+    "Storage & database" : "Сховище і база даних",
+    "Data folder" : "Каталог з даними",
+    "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP, щоб вибрати інший тип БД.",
+    "For more details check out the documentation." : "За подробицями зверніться до документації.",
+    "Performance warning" : "Попередження продуктивності",
+    "You chose SQLite as database." : "Ви вибрали SQLite як базу даних",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite слід використовувати лише для мінімалістичних серверних конфігурацій або для розробки. Для продуктових версій рекомендуємо використовувати базу даних іншого типу.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Якщо ви використовуєте клієнти для синхронізації файлів, використання SQLite вкрай не рекомендується.",
+    "Database user" : "Користувач бази даних",
+    "Database password" : "Пароль для бази даних",
+    "Database name" : "Назва бази даних",
+    "Database tablespace" : "Таблиця бази даних",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Будь ласка, вкажіть номер порту поряд з ім'ям вузла (напр., localhost:5432).",
+    "Database host" : "Вузол бази даних",
+    "Installing …" : "Встановлення…",
+    "Install" : "Встановити",
+    "Need help?" : "Потрібна допомога?",
+    "See the documentation" : "Подивитись документацію",
     "{name} version {version} and above" : "{name} версія {version} та вище",
     "This browser is not supported" : "Цей бравзер не підтримується",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ваш бравзер не підтримується. Будь ласка, оновіть бравзер до новішої версії або скористайтеся таким, що підтримується.",
@@ -247,11 +266,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Зазначте для пошуку серед наявних проєктів",
     "New in" : "Нові можливості",
     "View changelog" : "Подивитись зміни",
-    "Very weak password" : "Дуже слабкий пароль",
-    "Weak password" : "Слабкий пароль",
-    "So-so password" : "Такий собі пароль",
-    "Good password" : "Надійний пароль",
-    "Strong password" : "Надійний пароль",
     "No action available" : "Немає доступних дій",
     "Error fetching contact actions" : "Неможливо отримати дії з контактами",
     "Close \"{dialogTitle}\" dialog" : "Закрити меню \"{dialogTitle}\"",
@@ -289,34 +303,6 @@ OC.L10N.register(
     "File: %s" : "Файл: %s",
     "Line: %s" : "Рядок: %s",
     "Trace" : "Трасування",
-    "Security warning" : "Попередження безпеки",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог з даними та ваші файли можуть мати доступ з інтернету, оскільки файл .htaccess не дійсний.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Для отримання інформації про те, як правильно налаштувати свій сервер, перегляньте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацію</a>.",
-    "<strong>Create an admin account</strong>" : "<strong>Створити адміністративний обліковий запис</strong>",
-    "New admin account name" : "Ім'я нового адміністративного облікового запису",
-    "New admin password" : "Пароль нового адміністратора",
-    "Show password" : "Показати пароль",
-    "Toggle password visibility" : "Перемкнути видимість пароля",
-    "Storage & database" : "Сховище і база даних",
-    "Data folder" : "Каталог з даними",
-    "Configure the database" : "Налаштування бази даних",
-    "Only %s is available." : "Доступно тільки %s.",
-    "Install and activate additional PHP modules to choose other database types." : "Встановіть та активуйте додаткові модулі PHP, щоб вибрати інший тип БД.",
-    "For more details check out the documentation." : "За подробицями зверніться до документації.",
-    "Database account" : "Обліковий запис БД",
-    "Database password" : "Пароль для бази даних",
-    "Database name" : "Назва бази даних",
-    "Database tablespace" : "Таблиця бази даних",
-    "Database host" : "Вузол бази даних",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Будь ласка, вкажіть номер порту поряд з ім'ям вузла (напр., localhost:5432).",
-    "Performance warning" : "Попередження продуктивності",
-    "You chose SQLite as database." : "Ви вибрали SQLite як базу даних",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite слід використовувати лише для мінімалістичних серверних конфігурацій або для розробки. Для продуктових версій рекомендуємо використовувати базу даних іншого типу.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Якщо ви використовуєте клієнти для синхронізації файлів, використання SQLite вкрай не рекомендується.",
-    "Install" : "Встановити",
-    "Installing …" : "Встановлення…",
-    "Need help?" : "Потрібна допомога?",
-    "See the documentation" : "Подивитись документацію",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Схоже, ви намагаєтеся перевстановити Nextcloud. Однак файл CAN_INSTALL відсутній у вашому каталозі конфігурації. Щоб продовжити, створіть файл CAN_INSTALL у папці конфігурації.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Could not remove CAN_INSTALL from the config folder.Please remove this file manually.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Цей застосунок вимагає увімкнений JavaScript для коректної роботи. Будь ласка, активуйте {linkstart}JavaScript{linkend} та оновіть сторінку.",
@@ -385,7 +371,22 @@ OC.L10N.register(
     "Edit Profile" : "Редагувати профіль",
     "The headline and about sections will show up here" : "Тут відображатимуться заголовок і розділи про",
     "Error loading message template: {error}" : "Помилка при завантаженні шаблону повідомлення: {error}",
+    "Very weak password" : "Дуже слабкий пароль",
+    "Weak password" : "Слабкий пароль",
+    "So-so password" : "Такий собі пароль",
+    "Good password" : "Надійний пароль",
+    "Strong password" : "Надійний пароль",
     "Profile not found" : "Профіль не знайдено",
-    "The profile does not exist." : "Профіль не існує."
+    "The profile does not exist." : "Профіль не існує.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш каталог з даними та ваші файли можуть мати доступ з інтернету, оскільки файл .htaccess не дійсний.",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Для отримання інформації про те, як правильно налаштувати свій сервер, перегляньте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацію</a>.",
+    "<strong>Create an admin account</strong>" : "<strong>Створити адміністративний обліковий запис</strong>",
+    "New admin account name" : "Ім'я нового адміністративного облікового запису",
+    "New admin password" : "Пароль нового адміністратора",
+    "Show password" : "Показати пароль",
+    "Toggle password visibility" : "Перемкнути видимість пароля",
+    "Configure the database" : "Налаштування бази даних",
+    "Only %s is available." : "Доступно тільки %s.",
+    "Database account" : "Обліковий запис БД"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
