@@ -148,15 +148,15 @@ OC.L10N.register(
     "Log in with a device" : "Đăng nhập bằng thiết bị",
     "Login or email" : "Tên đăng nhập hoặc Email",
     "Your account is not setup for passwordless login." : "Tài khoản của bạn chưa được thiết lập để đăng nhập không cần mật khẩu.",
-    "Browser not supported" : "Trình duyệt không được hỗ trợ",
-    "Passwordless authentication is not supported in your browser." : "Xác thực không cần mật khẩu không được hỗ trợ trong trình duyệt của bạn.",
     "Your connection is not secure" : "Kết nối của bạn không an toàn",
     "Passwordless authentication is only available over a secure connection." : "Xác thực không cần mật khẩu chỉ khả dụng qua kết nối an toàn.",
+    "Browser not supported" : "Trình duyệt không được hỗ trợ",
+    "Passwordless authentication is not supported in your browser." : "Xác thực không cần mật khẩu không được hỗ trợ trong trình duyệt của bạn.",
     "Reset password" : "Khôi phục mật khẩu",
+    "Back to login" : "Quay lại trang đăng nhập",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Nếu tài khoản này tồn tại, một thông báo đặt lại mật khẩu đã được gửi đến địa chỉ email của nó. Nếu bạn không nhận được, hãy xác minh địa chỉ email và / hoặc tên tài khoản của bạn, kiểm tra thư mục spam / rác hoặc yêu cầu quản trị viên của bạn trợ giúp.",
     "Couldn't send reset email. Please contact your administrator." : "Không thể gửi thư điện tử yêu cầu thiết lập lại. Xin vui lòng liên hệ quản trị hệ thống",
     "Password cannot be changed. Please contact your administrator." : "Không thể thay đổi mật khẩu. Vui lòng liên hệ với quản trị viên của bạn.",
-    "Back to login" : "Quay lại trang đăng nhập",
     "New password" : "Mật khẩu mới",
     "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Các tệp của bạn được mã hóa. Sẽ không có cách nào để lấy lại dữ liệu của bạn sau khi mật khẩu của bạn được đặt lại. Nếu bạn không chắc chắn phải làm gì, vui lòng liên hệ với quản trị viên của bạn trước khi tiếp tục. Bạn có thực sự muốn tiếp tục?",
     "I know what I'm doing" : "Tôi biết tôi đang làm gì",
@@ -200,6 +200,25 @@ OC.L10N.register(
     "Login form is disabled." : "Trang đăng nhập bị vô hiệu.",
     "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Phương thức đăng nhập này đã bị tắt. Sử dụng hình thức đăng nhập khả dụng khác hoặc liên hệ quản trị viên.",
     "More actions" : "Nhiều hành động hơn",
+    "Security warning" : "Cảnh báo bảo mật",
+    "Storage & database" : "Lưu trữ & cơ sở dữ liệu",
+    "Data folder" : "Thư mục dữ liệu",
+    "Install and activate additional PHP modules to choose other database types." : "Cài đặt và kích hoạt các mô-đun PHP bổ sung để chọn các loại cơ sở dữ liệu khác.",
+    "For more details check out the documentation." : "Để biết thêm chi tiết, hãy kiểm tra tài liệu.",
+    "Performance warning" : "Cảnh báo hiệu suất",
+    "You chose SQLite as database." : "Bạn đã chọn SQLite làm cơ sở dữ liệu.",
+    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite chỉ nên được sử dụng cho các trường hợp tối thiểu và phát triển. Đối với sản xuất, chúng tôi khuyên bạn nên sử dụng một phụ trợ cơ sở dữ liệu khác.",
+    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Nếu bạn sử dụng máy khách để đồng bộ hóa tệp, việc sử dụng SQLite rất không được khuyến khích.",
+    "Database user" : "Người dùng cơ sở dữ liệu",
+    "Database password" : "Mật khẩu cơ sở dữ liệu",
+    "Database name" : "Tên cơ sở dữ liệu",
+    "Database tablespace" : "Cơ sở dữ liệu tablespace",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vui lòng xác định số cổng cùng với tên máy chủ lưu trữ (ví dụ: localhost: 5432).",
+    "Database host" : "Database host",
+    "Installing …" : "Đang cài đặt",
+    "Install" : "Cài đặt",
+    "Need help?" : "Cần hỗ trợ ?",
+    "See the documentation" : "Xem tài liệu",
     "{name} version {version} and above" : "{name} phiên bản {version} trở lên",
     "This browser is not supported" : "Trình duyệt này không được hỗ trợ",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Trình duyệt của bạn không được hỗ trợ. Vui lòng nâng cấp lên phiên bản mới hơn hoặc phiên bản được hỗ trợ.",
@@ -240,11 +259,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Nhập để tìm kiếm các dự án hiện có",
     "New in" : "Mới trong",
     "View changelog" : "Xem nhật ký thay đổi",
-    "Very weak password" : "Mật khẩu rất yếu",
-    "Weak password" : "Mật khẩu yếu",
-    "So-so password" : "Mật khẩu tạm được",
-    "Good password" : "Mật khẩu tốt",
-    "Strong password" : "Mật khẩu mạnh",
     "No action available" : "Không có hành động nào",
     "Error fetching contact actions" : "Lỗi khi nạp liên hệ",
     "Close \"{dialogTitle}\" dialog" : "Đóng hộp thoại \"{dialogTitle}\"",
@@ -281,31 +295,6 @@ OC.L10N.register(
     "File: %s" : "Tệp: %s",
     "Line: %s" : "Dòng: %s",
     "Trace" : "Theo dõi",
-    "Security warning" : "Cảnh báo bảo mật",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Thư mục và file dữ liệu của bạn có thể được truy cập từ internet bởi vì file .htaccess không hoạt động",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Để biết thông tin về cách cấu hình đúng máy chủ của bạn, vui lòng xem <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">tài liệu</a>.",
-    "Show password" : "Hiện mật khẩu",
-    "Toggle password visibility" : "Chuyển chế độ hiển thị mật khẩu",
-    "Storage & database" : "Lưu trữ & cơ sở dữ liệu",
-    "Data folder" : "Thư mục dữ liệu",
-    "Configure the database" : "Cấu hình cơ sở dữ liệu",
-    "Only %s is available." : "Chỉ %s khả dụng.",
-    "Install and activate additional PHP modules to choose other database types." : "Cài đặt và kích hoạt các mô-đun PHP bổ sung để chọn các loại cơ sở dữ liệu khác.",
-    "For more details check out the documentation." : "Để biết thêm chi tiết, hãy kiểm tra tài liệu.",
-    "Database account" : "Tài khoản CSDL",
-    "Database password" : "Mật khẩu cơ sở dữ liệu",
-    "Database name" : "Tên cơ sở dữ liệu",
-    "Database tablespace" : "Cơ sở dữ liệu tablespace",
-    "Database host" : "Database host",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Vui lòng xác định số cổng cùng với tên máy chủ lưu trữ (ví dụ: localhost: 5432).",
-    "Performance warning" : "Cảnh báo hiệu suất",
-    "You chose SQLite as database." : "Bạn đã chọn SQLite làm cơ sở dữ liệu.",
-    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite chỉ nên được sử dụng cho các trường hợp tối thiểu và phát triển. Đối với sản xuất, chúng tôi khuyên bạn nên sử dụng một phụ trợ cơ sở dữ liệu khác.",
-    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Nếu bạn sử dụng máy khách để đồng bộ hóa tệp, việc sử dụng SQLite rất không được khuyến khích.",
-    "Install" : "Cài đặt",
-    "Installing …" : "Đang cài đặt",
-    "Need help?" : "Cần hỗ trợ ?",
-    "See the documentation" : "Xem tài liệu",
     "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Có vẻ như bạn đang cố gắng cài đặt lại Nextcloud của mình. Tuy nhiên, CAN_INSTALL tệp bị thiếu trong thư mục cấu hình của bạn. Vui lòng tạo tệp CAN_INSTALL trong thư mục cấu hình của bạn để tiếp tục.",
     "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Không thể loại bỏ CAN_INSTALL khỏi thư mục cấu hình. Vui lòng xóa tệp này theo cách thủ công.",
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ứng dụng này yêu cầu JavaScript để hoạt động chính xác. Vui lòng {linkstart} bật JavaScript {linkend} và tải lại trang.",
@@ -374,7 +363,19 @@ OC.L10N.register(
     "Edit Profile" : "Chỉnh sửa hồ sơ",
     "The headline and about sections will show up here" : "Dòng tiêu đề và phần giới thiệu sẽ hiển thị ở đây",
     "Error loading message template: {error}" : "Lỗi khi tải mẫu thông điệp: {error}",
+    "Very weak password" : "Mật khẩu rất yếu",
+    "Weak password" : "Mật khẩu yếu",
+    "So-so password" : "Mật khẩu tạm được",
+    "Good password" : "Mật khẩu tốt",
+    "Strong password" : "Mật khẩu mạnh",
     "Profile not found" : "Không tìm thấy hồ sơ",
-    "The profile does not exist." : "Hồ sơ không tồn tại."
+    "The profile does not exist." : "Hồ sơ không tồn tại.",
+    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Thư mục và file dữ liệu của bạn có thể được truy cập từ internet bởi vì file .htaccess không hoạt động",
+    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Để biết thông tin về cách cấu hình đúng máy chủ của bạn, vui lòng xem <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">tài liệu</a>.",
+    "Show password" : "Hiện mật khẩu",
+    "Toggle password visibility" : "Chuyển chế độ hiển thị mật khẩu",
+    "Configure the database" : "Cấu hình cơ sở dữ liệu",
+    "Only %s is available." : "Chỉ %s khả dụng.",
+    "Database account" : "Tài khoản CSDL"
 },
 "nplurals=1; plural=0;");
